@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -108,11 +108,7 @@ ogmdvd_drive_chooser_init (OGMDvdDriveChooserIface  *iface)
 static void
 ogmdvd_drive_chooser_dialog_init (OGMDvdDriveChooserDialog *dialog)
 {
-  GtkWidget *alignment;
-  GtkWidget *image;
-  GtkWidget *label;
-  GtkWidget *hbox;
-  GtkWidget *vbox;
+  GtkWidget *area, *image, *label, *vbox;
 
   OGMDvdDeviceType type;
   gchar *device;
@@ -125,53 +121,29 @@ ogmdvd_drive_chooser_dialog_init (OGMDvdDriveChooserDialog *dialog)
 
   gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
-  dialog->priv->eject_button = gtk_button_new ();
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), dialog->priv->eject_button, FALSE, FALSE, 0);
+  area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+
+  dialog->priv->eject_button = gtk_button_new_with_mnemonic (_("_Eject"));
+  gtk_container_add (GTK_CONTAINER (area), dialog->priv->eject_button);
   gtk_widget_show (dialog->priv->eject_button);
 
   g_signal_connect_swapped (dialog->priv->eject_button, "clicked", G_CALLBACK (ogmdvd_drive_chooser_dialog_eject_clicked), dialog);
 
-  alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-  gtk_container_add (GTK_CONTAINER (dialog->priv->eject_button), alignment);
-  gtk_widget_show (alignment);
-
-  hbox = gtk_hbox_new (FALSE, 2);
-  gtk_container_add (GTK_CONTAINER (alignment), hbox);
-  gtk_widget_show (hbox);
-
   image = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
-  gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-  gtk_widget_show (image);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->eject_button), image);
 
-  label = gtk_label_new (_("_Eject"));
-  gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
-  dialog->priv->load_button = gtk_button_new ();
+  dialog->priv->load_button = gtk_button_new_with_mnemonic (_("_Load"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), dialog->priv->load_button, GTK_RESPONSE_OK);
   gtk_widget_show (dialog->priv->load_button);
 
-  alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-  gtk_container_add (GTK_CONTAINER (dialog->priv->load_button), alignment);
-  gtk_widget_show (alignment);
-
-  hbox = gtk_hbox_new (FALSE, 2);
-  gtk_container_add (GTK_CONTAINER (alignment), hbox);
-  gtk_widget_show (hbox);
-
   image = gtk_image_new_from_stock (GTK_STOCK_CDROM, GTK_ICON_SIZE_BUTTON);
-  gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-  gtk_widget_show (image);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->load_button), image);
 
-  label = gtk_label_new (_("_Load"));
-  gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), vbox);
   gtk_widget_show (vbox);
 
   label = gtk_label_new (_("<b>Select _DVD Drive:</b>"));
@@ -185,6 +157,8 @@ ogmdvd_drive_chooser_dialog_init (OGMDvdDriveChooserDialog *dialog)
   gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->chooser, TRUE, TRUE, 0);
   gtk_widget_show (dialog->priv->chooser);
 
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->priv->chooser);
+
   g_signal_connect_swapped (dialog->priv->chooser, "device-changed", 
       G_CALLBACK (ogmdvd_drive_chooser_dialog_device_changed), dialog);
 
