@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -199,14 +199,17 @@ gtk_widget_get_transient_window (GtkWidget *widget)
 {
   GtkWidget *parent;
 
-  parent = widget->parent;
-  while (parent->parent)
-    parent = parent->parent;
+  parent = gtk_widget_get_parent (widget);
+  while (parent)
+  {
+    widget = parent;
+    parent = gtk_widget_get_parent (widget);
+  }
 
-  if (!GTK_IS_WINDOW (parent))
+  if (!GTK_IS_WINDOW (widget))
     return NULL;
 
-  return parent;
+  return widget;
 }
 
 static gchar *
