@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -213,15 +213,19 @@ ogmrip_chooser_list_add_clicked (OGMRipChooserList *list, GtkWidget *button)
 static void
 ogmrip_chooser_list_remove_clicked (OGMRipChooserList *list, GtkWidget *button)
 {
-  gtk_container_remove (GTK_CONTAINER (list), button->parent->parent);
+  gtk_container_remove (GTK_CONTAINER (list),
+      gtk_widget_get_parent (gtk_widget_get_parent (button)));
 }
 
 static void
 ogmrip_chooser_list_more_clicked (OGMRipChooserList *list, GtkWidget *button)
 {
   OGMRipChooserListItem *item;
+  GtkWidget *parent;
 
-  item = g_object_get_data (G_OBJECT (button->parent->parent), "__ogmrip_chooser_list_item__");
+  parent = gtk_widget_get_parent (gtk_widget_get_parent (button));
+
+  item = g_object_get_data (G_OBJECT (parent), "__ogmrip_chooser_list_item__");
   if (item)
     g_signal_emit (G_OBJECT (list), signals[MORE_CLICKED], 0, item->chooser);
 }
@@ -243,8 +247,14 @@ ogmrip_chooser_list_dispose (GObject *gobject)
 static void
 ogmrip_chooser_list_show (GtkWidget *widget)
 {
-  if (widget && widget->parent)
-    gtk_widget_show (widget->parent);
+  if (widget)
+  {
+    GtkWidget *parent;
+
+    parent = gtk_widget_get_parent (widget);
+    if (parent)
+      gtk_widget_show (parent);
+  }
 
   (*GTK_WIDGET_CLASS (ogmrip_chooser_list_parent_class)->show) (widget);
 }
@@ -259,7 +269,12 @@ ogmrip_chooser_list_add_internal (GtkContainer *container, GtkWidget *chooser)
 
   if (G_TYPE_CHECK_INSTANCE_TYPE (chooser, list->priv->child_type))
   {
-    len = g_list_length (GTK_BOX (container)->children);
+    GList *children;
+
+    children = gtk_container_get_children (container);
+    len = g_list_length (children);
+    g_list_free (children);
+
     if (list->priv->max < 0 || len < list->priv->max)
     {
       GtkWidget *child, *button;
@@ -348,24 +363,23 @@ void
 ogmrip_chooser_list_set_max (OGMRipChooserList *list, guint max)
 {
   GList *link, *children;
-  GtkWidget *button;
-  GtkBoxChild *child;
+  GtkWidget *button, *child;
   guint i;
 
   g_return_if_fail (OGMRIP_IS_CHOOSER_LIST (list));
 
   list->priv->max = MAX (max, 1);
 
-  children = g_list_copy (GTK_BOX (list)->children);
+  children = gtk_container_get_children (GTK_CONTAINER (list));
   for (i = 0, link = children; link; i ++, link = link->next)
   {
     child = link->data;
 
     if (i >= max)
-      gtk_container_remove (GTK_CONTAINER (list), child->widget);
+      gtk_container_remove (GTK_CONTAINER (list), child);
     else
     {
-      button = ogmrip_chooser_list_child_get_add_button (child->widget);
+      button = ogmrip_chooser_list_child_get_add_button (child);
       gtk_widget_set_sensitive (button, max < 0 || i < max - 1);
     }
   }
@@ -414,11 +428,14 @@ ogmrip_chooser_list_add (OGMRipChooserList *list, GtkWidget *chooser)
 void
 ogmrip_chooser_list_remove (OGMRipChooserList *list, GtkWidget *chooser)
 {
+  GtkWidget *parent;
+
   g_return_if_fail (OGMRIP_CHOOSER_LIST (list));
   g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (chooser, list->priv->child_type));
 
-  if (chooser->parent)
-    gtk_container_remove (GTK_CONTAINER (list), chooser->parent);
+  parent = gtk_widget_get_parent (chooser);
+  if (parent)
+    gtk_container_remove (GTK_CONTAINER (list), parent);
 }
 
 /**
@@ -431,16 +448,12 @@ void
 ogmrip_chooser_list_clear (OGMRipChooserList *list)
 {
   GList *link, *children;
-  GtkBoxChild *box_child;
 
   g_return_if_fail (OGMRIP_IS_CHOOSER_LIST (list));
 
-  children = g_list_copy (GTK_BOX (list)->children);
+  children = gtk_container_get_children (GTK_CONTAINER (list));
   for (link = children; link; link = link->next)
-  {
-    box_child = link->data;
-    gtk_container_remove (GTK_CONTAINER (list), box_child->widget);
-  }
+    gtk_container_remove (GTK_CONTAINER (list), GTK_WIDGET (link->data));
   g_list_free (children);
 }
 
@@ -456,20 +469,18 @@ ogmrip_chooser_list_clear (OGMRipChooserList *list)
 void
 ogmrip_chooser_list_foreach (OGMRipChooserList *list, OGMRipSourceType type, GFunc func, gpointer data)
 {
-  GList *link;
+  GList *children, *link;
   gint source_type;
 
   OGMRipSource *source;
-  GtkBoxChild *box_child;
-
   OGMRipChooserListItem *item;
 
   g_return_if_fail (OGMRIP_IS_CHOOSER_LIST (list));
 
-  for (link = GTK_BOX (list)->children; link; link = link->next)
+  children = gtk_container_get_children (GTK_CONTAINER (list));
+  for (link = children; link; link = link->next)
   {
-    box_child = link->data;
-    item = g_object_get_data (G_OBJECT (box_child->widget), "__ogmrip_chooser_list_item__");
+    item = g_object_get_data (G_OBJECT (link->data), "__ogmrip_chooser_list_item__");
 
     source = ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (item->chooser), &source_type);
 
@@ -484,6 +495,7 @@ ogmrip_chooser_list_foreach (OGMRipChooserList *list, OGMRipSourceType type, GFu
         (* func) (item->chooser, data);
     }
   }
+  g_list_free (children);
 }
 
 /**
@@ -497,22 +509,22 @@ ogmrip_chooser_list_foreach (OGMRipChooserList *list, OGMRipSourceType type, GFu
 gint
 ogmrip_chooser_list_length (OGMRipChooserList *list)
 {
-  GList *link;
-  GtkBoxChild *box_child;
+  GList *children, *link;
   gint n_children = 0;
 
   OGMRipChooserListItem *item;
 
   g_return_val_if_fail (OGMRIP_IS_CHOOSER_LIST (list), -1);
 
-  for (link = GTK_BOX (list)->children; link; link = link->next)
+  children = gtk_container_get_children (GTK_CONTAINER (list));
+  for (link = children; link; link = link->next)
   {
-    box_child = link->data;
-    item = g_object_get_data (G_OBJECT (box_child->widget), "__ogmrip_chooser_list_item__");
+    item = g_object_get_data (G_OBJECT (link->data), "__ogmrip_chooser_list_item__");
 
     if (ogmrip_source_chooser_get_active (OGMRIP_SOURCE_CHOOSER (item->chooser), NULL))
       n_children ++;
   }
+  g_list_free (children);
 
   return n_children;
 }
@@ -530,15 +542,15 @@ GtkWidget *
 ogmrip_chooser_list_nth (OGMRipChooserList *list, guint n)
 {
   OGMRipChooserListItem *item;
-  GtkBoxChild *box_child;
+  GtkWidget *child;
 
   g_return_val_if_fail (OGMRIP_IS_CHOOSER_LIST (list), NULL);
 
-  box_child = g_list_nth_data (GTK_BOX (list)->children, n);
-  if (!box_child)
+  child = gtk_box_get_nth_child (GTK_BOX (list), n);
+  if (!child)
     return NULL;
 
-  item = g_object_get_data (G_OBJECT (box_child->widget), "__ogmrip_chooser_list_item__");
+  item = g_object_get_data (G_OBJECT (child), "__ogmrip_chooser_list_item__");
   if (!item)
     return NULL;
 
