@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -269,45 +269,6 @@ gtk_window_set_icon_from_stock (GtkWindow *window, const gchar *stock_id)
   g_object_unref (pixbuf);
 }
 
-/**
- * gtk_button_new_with_image:
- * @text: The text you want the #GtkLabel to hold
- * @stock_id: the name of the stock item
- *
- * Creates a new #GtkButton containing the given text and the image from a stock item.
- *
- * Returns: A new #GtkButton
- */
-GtkWidget *
-gtk_button_new_with_image (const gchar *text, const gchar *stock_id)
-{
-  GtkWidget *button, *alignment, *box, *image, *label;
-
-  g_return_val_if_fail (text != NULL, NULL);
-  g_return_val_if_fail (stock_id != NULL, NULL);
-
-  button = gtk_button_new ();
-
-  alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-  gtk_container_add (GTK_CONTAINER (button), alignment);
-  gtk_widget_show (alignment);
-
-  box = gtk_hbox_new (FALSE, 2);
-  gtk_container_add (GTK_CONTAINER (alignment), box);
-  gtk_widget_show (box);
-
-  image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-  gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
-  gtk_widget_show (image);
-
-  label = gtk_label_new (text);
-  gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
-  gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
-  return button;
-}
-
 /**
  * gtk_radio_button_get_active:
  * @radio: Any #GtkRadioButton of the group
@@ -432,19 +393,25 @@ gtk_label_get_int (GtkLabel *label)
 GtkWidget *
 gtk_box_get_nth_child (GtkBox *box, gint n)
 {
-  GList *link;
+  GList *children, *link;
+  GtkWidget *child;
 
   g_return_val_if_fail (GTK_IS_BOX (box), NULL);
 
-  if (n < 0)
-    link = g_list_last (box->children);
-  else
-    link = g_list_nth (box->children, n);
-
-  if (!link)
+  children = gtk_container_get_children (GTK_CONTAINER (box));
+  if (!children)
     return NULL;
 
-  return ((GtkBoxChild *)(link->data))->widget;
+  if (n < 0)
+    link = g_list_last (children);
+  else
+    link = g_list_nth (children, n);
+
+  child = link->data;
+
+  g_list_free (children);
+
+  return child;
 }
 
 /**
@@ -460,26 +427,23 @@ gtk_box_get_nth_child (GtkBox *box, gint n)
 void
 gtk_dialog_set_response_visible (GtkDialog *dialog, gint response_id, gboolean setting)
 {
-  GList *children;
-  GList *tmp_list;
+  GList *children, *child;
+  GtkWidget *area, *widget;
+  gint rid;
 
   g_return_if_fail (GTK_IS_DIALOG (dialog));
 
-  children = gtk_container_get_children (GTK_CONTAINER (dialog->action_area));
+  area = gtk_dialog_get_action_area (dialog);
 
-  tmp_list = children;
-  while (tmp_list != NULL)
-    {
-      GtkWidget *widget = tmp_list->data;
-      gint rid;
+  children = gtk_container_get_children (GTK_CONTAINER (area));
+  for (child = children; child; child = child->next)
+  {
+    widget = child->data;
 
-      rid = gtk_dialog_get_response_for_widget (dialog, widget);
-
-      if (rid == response_id)
-        g_object_set (widget, "visible", setting, NULL);
-
-      tmp_list = g_list_next (tmp_list);
-    }
+    rid = gtk_dialog_get_response_for_widget (dialog, widget);
+    if (rid == response_id)
+      g_object_set (widget, "visible", setting, NULL);
+  }
 
   g_list_free (children);
 }
@@ -579,19 +543,21 @@ ogmrip_message_dialog_newv (GtkWindow *parent, GtkMessageType type, const gchar
       break;
   }
 
-  message = g_strdup_vprintf (format, args);
   dialog = gtk_message_dialog_new (parent,
-      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, type, buttons, "%s", message);
+      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, type, buttons, NULL);
+
+  if (!dialog)
+    return NULL;
+
+  message = g_strdup_vprintf (format, args);
+  gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), message);
   g_free (message);
 
-  if (dialog)
-  {
-    if (stock_id)
-      gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), stock_id);
+  if (stock_id)
+    gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), stock_id);
 
-    gtk_window_set_gravity (GTK_WINDOW (dialog), GDK_GRAVITY_CENTER);
-    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-  }
+  gtk_window_set_gravity (GTK_WINDOW (dialog), GDK_GRAVITY_CENTER);
+  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
   return dialog;
 }
@@ -653,7 +619,6 @@ ogmrip_message_dialog (GtkWindow *parent, GtkMessageType type, const gchar *form
   {
     gint response;
 
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     response = gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
@@ -1094,7 +1059,7 @@ ogmrip_load_dvd_dialog_new (GtkWindow *parent, OGMDvdDisc *disc, const gchar *na
       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
       GTK_MESSAGE_INFO, cancellable ? GTK_BUTTONS_CANCEL : GTK_BUTTONS_NONE,
       "<b>%s</b>\n\n%s", name, _("Please insert the DVD required to encode this title."));
-  gtk_label_set_selectable (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), FALSE);
+  // gtk_label_set_selectable (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), FALSE);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_DIALOG_INFO);
 
   g_signal_connect_swapped_while_alive (drive, "medium-added", G_CALLBACK (gtk_dialog_response_accept), dialog);
