@@ -1,5 +1,5 @@
 /* OGMRip - A wrapper library around libdvdread
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -74,9 +74,6 @@ struct _OGMRipSourceChooserWidgetPriv
 {
   OGMDvdTitle *title;
 
-  GtkWidget *dialog;
-  GtkWidget *lang_combo;
-
   GtkTreePath *prev_path;
 };
 
@@ -94,6 +91,7 @@ static void ogmrip_audio_chooser_widget_set_property    (GObject      *gobject,
                                                          guint        property_id,
                                                          const GValue *value,
                                                          GParamSpec   *pspec);
+static void ogmrip_audio_chooser_widget_changed         (GtkComboBox  *combo);
 static void ogmrip_subtitle_chooser_widget_dispose      (GObject      *gobject);
 static void ogmrip_subtitle_chooser_widget_finalize     (GObject      *gobject);
 static void ogmrip_subtitle_chooser_widget_get_property (GObject      *gobject,
@@ -104,11 +102,7 @@ static void ogmrip_subtitle_chooser_widget_set_property (GObject      *gobject,
                                                          guint        property_id,
                                                          const GValue *value,
                                                          GParamSpec   *pspec);
-
-/*
- * GtkComboBox funcs
- */
-static void ogmrip_source_chooser_widget_changed (GtkComboBox *combo_box);
+static void ogmrip_subtitle_chooser_widget_changed      (GtkComboBox  *combo);
 
 /*
  * OGMRipSourceChooser funcs
@@ -127,41 +121,36 @@ static void           ogmrip_source_chooser_widget_select_language (OGMRipSource
  * Internal functions
  */
 
-static void     ogmrip_audio_chooser_widget_init           (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_audio_chooser_widget_class_init     (OGMRipSourceChooserWidgetClass *klass);
+static void     ogmrip_audio_chooser_widget_init             (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_audio_chooser_widget_class_init       (OGMRipSourceChooserWidgetClass *klass);
 
-static void     ogmrip_subtitle_chooser_widget_init        (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_subtitle_chooser_widget_class_init  (OGMRipSourceChooserWidgetClass *klass);
+static void     ogmrip_subtitle_chooser_widget_init          (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_subtitle_chooser_widget_class_init    (OGMRipSourceChooserWidgetClass *klass);
 
-static void     ogmrip_source_chooser_widget_construct     (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_source_chooser_widget_dispose       (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_source_chooser_widget_finalize      (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_source_chooser_widget_get_property  (OGMRipSourceChooser            *chooser,
-                                                            guint                          property_id,
-                                                            GValue                         *value,
-                                                            GParamSpec                     *pspec);
-static void     ogmrip_source_chooser_widget_set_property  (OGMRipSourceChooser            *chooser,
-                                                            guint                          property_id,
-                                                            const GValue                   *value,
-                                                            GParamSpec                     *pspec);
-static gboolean ogmrip_source_chooser_widget_sep_func      (GtkTreeModel                   *model,
-                                                            GtkTreeIter                    *iter,
-                                                            gpointer                       data);
-static void     ogmrip_source_chooser_widget_clear         (OGMRipSourceChooserWidget      *chooser);
-static void     ogmrip_source_chooser_widget_set_file      (OGMRipSourceChooserWidget      *chooser,
-                                                            const gchar                    *filename,
-                                                            gint                           language);
-static gboolean ogmrip_source_chooser_widget_get_file_iter (OGMRipSourceChooserWidget      *chooser,
-                                                            GtkTreeModel                   **model,
-                                                            GtkTreeIter                    *iter);
-
-/*
- * Internal signals
- */
-
-static void ogmrip_source_chooser_widget_dialog_response   (OGMRipSourceChooserWidget *chooser,
-                                                            gint                      response,
-                                                            GtkWidget                 *dialog);
+static void     ogmrip_source_chooser_widget_construct       (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_source_chooser_widget_dispose         (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_source_chooser_widget_finalize        (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_source_chooser_widget_get_property    (OGMRipSourceChooser            *chooser,
+                                                              guint                          property_id,
+                                                              GValue                         *value,
+                                                              GParamSpec                     *pspec);
+static void     ogmrip_source_chooser_widget_set_property    (OGMRipSourceChooser            *chooser,
+                                                              guint                          property_id,
+                                                              const GValue                   *value,
+                                                              GParamSpec                     *pspec);
+static gboolean ogmrip_source_chooser_widget_sep_func        (GtkTreeModel                   *model,
+                                                              GtkTreeIter                    *iter,
+                                                              gpointer                       data);
+static void     ogmrip_source_chooser_widget_clear           (OGMRipSourceChooserWidget      *chooser);
+static void     ogmrip_source_chooser_widget_set_file        (OGMRipSourceChooserWidget      *chooser,
+                                                              const gchar                    *filename,
+                                                              gint                           language);
+static gboolean ogmrip_source_chooser_widget_get_file_iter   (OGMRipSourceChooserWidget      *chooser,
+                                                              GtkTreeModel                   **model,
+                                                              GtkTreeIter                    *iter);
+static void     ogmrip_source_chooser_widget_dialog_response (OGMRipSourceChooserWidget      *chooser,
+                                                              gint                           response,
+                                                              GtkWidget                      *dialog);
 
 extern const gchar *ogmdvd_languages[][3];
 extern const guint  ogmdvd_nlanguages;
@@ -169,6 +158,89 @@ extern const guint  ogmdvd_nlanguages;
 static gpointer ogmrip_audio_chooser_widget_parent_class = NULL;
 static gpointer ogmrip_subtitle_chooser_widget_parent_class = NULL;
 
+static GtkWidget *
+ogmrip_source_chooser_construct_file_chooser_dialog (gboolean audio)
+{
+  GtkWidget *dialog, *alignment, *hbox, *label, *combo;
+  GtkFileFilter *filter;
+
+  const gchar* const *langs;
+  gchar *str, lang[2];
+  guint i;
+
+  dialog = gtk_file_chooser_dialog_new (NULL, NULL,
+      GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+      GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
+
+  g_signal_connect (dialog, "delete_event", G_CALLBACK (gtk_true), NULL);
+
+  filter = gtk_file_filter_new ();
+
+  if (audio)
+  {
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Select an audio file"));
+
+    gtk_file_filter_add_mime_type (filter, "audio/*");
+    gtk_file_filter_add_mime_type (filter, "application/ogg");
+  }
+  else
+  {
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Select a subtitles file"));
+
+    gtk_file_filter_add_mime_type (filter, "text/*");
+  }
+
+  gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+  alignment = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
+  gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog), alignment);
+  gtk_widget_show (alignment);
+
+  hbox = gtk_hbox_new (FALSE, 6);
+  gtk_container_add (GTK_CONTAINER (alignment), hbox);
+  gtk_widget_show (hbox);
+
+  label = gtk_label_new_with_mnemonic (_("_Language:"));
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  combo = gtk_combo_box_new_text ();
+  gtk_box_pack_start (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
+  gtk_widget_show (combo);
+
+  g_object_set_data (G_OBJECT (dialog), "__ogmrip_source_chooser_widget_lang_combo__", combo);
+
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
+
+  langs = g_get_language_names ();
+  if (!langs[0] || strcmp (langs[0], "C") == 0 || strcmp (langs[0], "POSIX") == 0)
+  {
+    lang[0] = 'e';
+    lang[1] = 'n';
+  }
+  else
+  {
+    lang[0] = langs[0][0];
+    lang[1] = langs[0][1];
+  }
+
+  for (i = 2; i < ogmdvd_nlanguages; i++)
+  {
+    str = g_strdup_printf ("%s (%s)", ogmdvd_languages[i][OGMDVD_LANGUAGE_NAME],
+        ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1]);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), str);
+    g_free (str);
+
+    if (strncmp (ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1], lang, 2) == 0)
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), i - 2);
+  }
+
+  return dialog;
+}
+
 static void
 ogmrip_audio_chooser_widget_class_intern_init (gpointer klass)
 {
@@ -218,7 +290,7 @@ ogmrip_audio_chooser_widget_class_init (OGMRipSourceChooserWidgetClass *klass)
   object_class->set_property = ogmrip_audio_chooser_widget_set_property;
 
   combo_box_class = (GtkComboBoxClass *) klass;
-  combo_box_class->changed = ogmrip_source_chooser_widget_changed;
+  combo_box_class->changed = ogmrip_audio_chooser_widget_changed;
 
   g_object_class_override_property (object_class, PROP_TITLE, "title");
   g_object_class_override_property (object_class, PROP_SOURCE, "source");
@@ -232,11 +304,6 @@ ogmrip_audio_chooser_widget_init (OGMRipSourceChooserWidget *chooser)
   chooser->priv = OGMRIP_AUDIO_CHOOSER_WIDGET_GET_PRIVATE (chooser);
 
   ogmrip_source_chooser_widget_construct (chooser);
-
-  gtk_window_set_title (GTK_WINDOW (chooser->priv->dialog), _("Select an audio file"));
-
-  g_signal_connect_swapped (chooser->priv->dialog, "response",
-      G_CALLBACK (ogmrip_source_chooser_widget_dialog_response), chooser);
 }
 
 static void
@@ -267,6 +334,50 @@ ogmrip_audio_chooser_widget_set_property (GObject *gobject, guint property_id, c
   ogmrip_source_chooser_widget_set_property (OGMRIP_SOURCE_CHOOSER (gobject), property_id, value, pspec);
 }
 
+static void
+ogmrip_audio_chooser_widget_changed (GtkComboBox *combo)
+{
+  GtkTreeIter iter;
+
+  if (gtk_combo_box_get_active_iter (combo, &iter))
+  {
+    OGMRipSourceChooserWidget *chooser;
+    GtkTreeModel *model;
+    gint type;
+
+    chooser = OGMRIP_AUDIO_CHOOSER_WIDGET (combo);
+
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+    gtk_tree_model_get (model, &iter, TYPE_COLUMN, &type, -1);
+
+    if (type == ROW_TYPE_OTHER)
+    {
+      GtkWidget *dialog, *toplevel;
+      gint response;
+
+      dialog = ogmrip_source_chooser_construct_file_chooser_dialog (TRUE);
+
+      toplevel = gtk_widget_get_toplevel (GTK_WIDGET (chooser));
+#if GTK_CHECK_VERSION(2,18,0)
+      if (gtk_widget_is_toplevel (toplevel) && GTK_IS_WINDOW (toplevel))
+#else
+      if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_IS_WINDOW (toplevel))
+#endif
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
+
+      response = gtk_dialog_run (GTK_DIALOG (dialog));
+      ogmrip_source_chooser_widget_dialog_response (chooser, response, dialog);
+      gtk_widget_destroy (dialog);
+    }
+    else
+    {
+      if (chooser->priv->prev_path)
+        gtk_tree_path_free (chooser->priv->prev_path);
+      chooser->priv->prev_path = gtk_tree_model_get_path (model, &iter);
+    }
+  }
+}
+
 static void
 ogmrip_subtitle_chooser_widget_class_intern_init (gpointer klass)
 {
@@ -316,7 +427,7 @@ ogmrip_subtitle_chooser_widget_class_init (OGMRipSourceChooserWidgetClass *klass
   object_class->set_property = ogmrip_subtitle_chooser_widget_set_property;
 
   combo_box_class = (GtkComboBoxClass *) klass;
-  combo_box_class->changed = ogmrip_source_chooser_widget_changed;
+  combo_box_class->changed = ogmrip_subtitle_chooser_widget_changed;
 
   g_object_class_override_property (object_class, PROP_TITLE, "title");
   g_object_class_override_property (object_class, PROP_SOURCE, "source");
@@ -330,11 +441,6 @@ ogmrip_subtitle_chooser_widget_init (OGMRipSourceChooserWidget *chooser)
   chooser->priv = OGMRIP_SUBTITLE_CHOOSER_WIDGET_GET_PRIVATE (chooser);
 
   ogmrip_source_chooser_widget_construct (chooser);
-
-  gtk_window_set_title (GTK_WINDOW (chooser->priv->dialog), _("Select a subtitles file"));
-
-  g_signal_connect_swapped (chooser->priv->dialog, "response",
-      G_CALLBACK (ogmrip_source_chooser_widget_dialog_response), chooser);
 }
 
 static void
@@ -342,7 +448,7 @@ ogmrip_subtitle_chooser_widget_dispose (GObject *gobject)
 {
   ogmrip_source_chooser_widget_dispose (OGMRIP_SUBTITLE_CHOOSER_WIDGET (gobject));
 
-  (*G_OBJECT_CLASS (ogmrip_audio_chooser_widget_parent_class)->dispose) (gobject);
+  (*G_OBJECT_CLASS (ogmrip_subtitle_chooser_widget_parent_class)->dispose) (gobject);
 }
 
 static void
@@ -350,7 +456,7 @@ ogmrip_subtitle_chooser_widget_finalize (GObject *gobject)
 {
   ogmrip_source_chooser_widget_finalize (OGMRIP_SUBTITLE_CHOOSER_WIDGET (gobject));
 
-  (*G_OBJECT_CLASS (ogmrip_audio_chooser_widget_parent_class)->finalize) (gobject);
+  (*G_OBJECT_CLASS (ogmrip_subtitle_chooser_widget_parent_class)->finalize) (gobject);
 }
 
 static void
@@ -365,6 +471,50 @@ ogmrip_subtitle_chooser_widget_set_property (GObject *gobject, guint property_id
   ogmrip_source_chooser_widget_set_property (OGMRIP_SOURCE_CHOOSER (gobject), property_id, value, pspec);
 }
 
+static void
+ogmrip_subtitle_chooser_widget_changed (GtkComboBox *combo)
+{
+  GtkTreeIter iter;
+
+  if (gtk_combo_box_get_active_iter (combo, &iter))
+  {
+    OGMRipSourceChooserWidget *chooser;
+    GtkTreeModel *model;
+    gint type;
+
+    chooser = OGMRIP_SUBTITLE_CHOOSER_WIDGET (combo);
+
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+    gtk_tree_model_get (model, &iter, TYPE_COLUMN, &type, -1);
+
+    if (type == ROW_TYPE_OTHER)
+    {
+      GtkWidget *dialog, *toplevel;
+      gint response;
+
+      dialog = ogmrip_source_chooser_construct_file_chooser_dialog (FALSE);
+
+      toplevel = gtk_widget_get_toplevel (GTK_WIDGET (chooser));
+#if GTK_CHECK_VERSION(2,18,0)
+      if (gtk_widget_is_toplevel (toplevel) && GTK_IS_WINDOW (toplevel))
+#else
+      if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_IS_WINDOW (toplevel))
+#endif
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
+
+      response = gtk_dialog_run (GTK_DIALOG (dialog));
+      ogmrip_source_chooser_widget_dialog_response (chooser, response, dialog);
+      gtk_widget_destroy (dialog);
+    }
+    else
+    {
+      if (chooser->priv->prev_path)
+        gtk_tree_path_free (chooser->priv->prev_path);
+      chooser->priv->prev_path = gtk_tree_model_get_path (model, &iter);
+    }
+  }
+}
+
 static void
 ogmrip_source_chooser_init (OGMRipSourceChooserIface *iface)
 {
@@ -377,15 +527,9 @@ ogmrip_source_chooser_init (OGMRipSourceChooserIface *iface)
 static void
 ogmrip_source_chooser_widget_construct (OGMRipSourceChooserWidget *chooser)
 {
-  GtkFileFilter *filter;
-  GtkWidget *alignment, *hbox, *label;
   GtkCellRenderer *cell;
   GtkListStore *store;
 
-  const gchar* const *langs;
-  gchar *str, lang[2];
-  guint i;
-
   store = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_POINTER);
   gtk_combo_box_set_model (GTK_COMBO_BOX (chooser), GTK_TREE_MODEL (store));
   g_object_unref (store);
@@ -396,69 +540,6 @@ ogmrip_source_chooser_widget_construct (OGMRipSourceChooserWidget *chooser)
   cell = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (chooser), cell, TRUE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (chooser), cell, "text", TEXT_COLUMN, NULL);
-
-  chooser->priv->dialog = gtk_file_chooser_dialog_new (NULL, NULL,
-      GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-  gtk_dialog_set_default_response (GTK_DIALOG (chooser->priv->dialog), GTK_RESPONSE_ACCEPT);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (chooser->priv->dialog),
-      GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
-
-  g_signal_connect_swapped (chooser->priv->dialog, "delete_event",
-      G_CALLBACK (gtk_true), chooser);
-
-  filter = gtk_file_filter_new ();
-
-  if (OGMRIP_IS_AUDIO_CHOOSER_WIDGET (chooser))
-  {
-    gtk_file_filter_add_mime_type (filter, "audio/*");
-    gtk_file_filter_add_mime_type (filter, "application/ogg");
-  }
-  else
-    gtk_file_filter_add_mime_type (filter, "text/*");
-
-  gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (chooser->priv->dialog), filter);
-
-  alignment = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
-  gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (chooser->priv->dialog), alignment);
-  gtk_widget_show (alignment);
-
-  hbox = gtk_hbox_new (FALSE, 6);
-  gtk_container_add (GTK_CONTAINER (alignment), hbox);
-  gtk_widget_show (hbox);
-
-  label = gtk_label_new_with_mnemonic (_("_Language:"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
-  chooser->priv->lang_combo = gtk_combo_box_new_text ();
-  gtk_box_pack_start (GTK_BOX (hbox), chooser->priv->lang_combo, TRUE, TRUE, 0);
-  gtk_widget_show (chooser->priv->lang_combo);
-
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), chooser->priv->lang_combo);
-
-  langs = g_get_language_names ();
-  if (!langs[0] || strcmp (langs[0], "C") == 0 || strcmp (langs[0], "POSIX") == 0)
-  {
-    lang[0] = 'e';
-    lang[1] = 'n';
-  }
-  else
-  {
-    lang[0] = langs[0][0];
-    lang[1] = langs[0][1];
-  }
-
-  for (i = 2; i < ogmdvd_nlanguages; i++)
-  {
-    str = g_strdup_printf ("%s (%s)", ogmdvd_languages[i][OGMDVD_LANGUAGE_NAME],
-        ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1]);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (chooser->priv->lang_combo), str);
-    g_free (str);
-
-    if (strncmp (ogmdvd_languages[i][OGMDVD_LANGUAGE_ISO639_1], lang, 2) == 0)
-      gtk_combo_box_set_active (GTK_COMBO_BOX (chooser->priv->lang_combo), i - 2);
-  }
 }
 
 static void
@@ -477,9 +558,6 @@ ogmrip_source_chooser_widget_finalize (OGMRipSourceChooserWidget *chooser)
   if (chooser->priv->prev_path)
     gtk_tree_path_free (chooser->priv->prev_path);
   chooser->priv->prev_path = NULL;
-
-  if (chooser->priv->dialog)
-    gtk_widget_destroy (chooser->priv->dialog);
 }
 
 static void
@@ -512,59 +590,6 @@ ogmrip_source_chooser_widget_set_property (OGMRipSourceChooser *chooser, guint p
   }
 }
 
-static void
-ogmrip_source_chooser_widget_changed (GtkComboBox *combo_box)
-{
-  GtkTreeIter iter;
-
-  if (gtk_combo_box_get_active_iter (combo_box, &iter))
-  {
-    OGMRipSourceChooserWidget *chooser;
-    GtkTreeModel *model;
-    gint type;
-
-    if (OGMRIP_IS_AUDIO_CHOOSER_WIDGET (combo_box))
-      chooser = OGMRIP_AUDIO_CHOOSER_WIDGET (combo_box);
-    else
-      chooser = OGMRIP_SUBTITLE_CHOOSER_WIDGET (combo_box);
-
-    model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo_box));
-    gtk_tree_model_get (model, &iter, TYPE_COLUMN, &type, -1);
-
-    if (type == ROW_TYPE_OTHER)
-    {
-#if GTK_CHECK_VERSION(2,18,0)
-      if (!gtk_widget_get_visible (chooser->priv->dialog))
-#else
-      if (!GTK_WIDGET_VISIBLE (chooser->priv->dialog))
-#endif
-      {
-        GtkWidget *toplevel;
-
-        toplevel = gtk_widget_get_toplevel (GTK_WIDGET (chooser));
-
-        if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_IS_WINDOW (toplevel))
-        {
-          if (GTK_WINDOW (toplevel) != gtk_window_get_transient_for (GTK_WINDOW (chooser->priv->dialog)))
-            gtk_window_set_transient_for (GTK_WINDOW (chooser->priv->dialog), GTK_WINDOW (toplevel));
-
-          gtk_window_set_modal (GTK_WINDOW (chooser->priv->dialog),
-              gtk_window_get_modal (GTK_WINDOW (toplevel)));
-        }
-      }
-
-      gtk_widget_set_sensitive (GTK_WIDGET (chooser), FALSE);
-      gtk_window_present (GTK_WINDOW (chooser->priv->dialog));
-    }
-    else
-    {
-      if (chooser->priv->prev_path)
-        gtk_tree_path_free (chooser->priv->prev_path);
-      chooser->priv->prev_path = gtk_tree_model_get_path (model, &iter);
-    }
-  }
-}
-
 static gboolean
 ogmrip_source_chooser_widget_sep_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
@@ -780,17 +805,19 @@ ogmrip_source_chooser_widget_dialog_response (OGMRipSourceChooserWidget *chooser
 {
   if (response == GTK_RESPONSE_ACCEPT)
   {
+    GtkWidget *combo;
     const gchar *str;
     gchar *filename;
     gint lang;
 
-    lang = gtk_combo_box_get_active (GTK_COMBO_BOX (chooser->priv->lang_combo));
+    combo = g_object_get_data (G_OBJECT (dialog), "__ogmrip_source_chooser_widget_lang_combo__");
+    lang = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
     lang = CLAMP (lang, 0, ogmdvd_nlanguages - 3) + 2;
     str = ogmdvd_languages[lang][OGMDVD_LANGUAGE_ISO639_1];
     lang = (str[0] << 8) | str[1];
 
-    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser->priv->dialog));
+    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
     ogmrip_source_chooser_widget_set_file (chooser, filename, lang);
     g_free (filename);
   }
