@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -231,7 +231,7 @@ ogmrip_x264_dialog_class_init (OGMRipX264DialogClass *klass)
 static void
 ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
 {
-  GtkWidget *widget;
+  GtkWidget *area, *widget;
   GladeXML *xml;
 
   xml = glade_xml_new (OGMRIP_DATA_DIR "/" OGMRIP_GLADE_FILE, OGMRIP_GLADE_ROOT, NULL);
@@ -251,8 +251,10 @@ ogmrip_x264_dialog_init (OGMRipX264Dialog *dialog)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   widget = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), widget);
   gtk_widget_show (widget);
 
   dialog->profile_combo = glade_xml_get_widget (xml, "profile-combo");
