@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redisectionibute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -155,7 +155,7 @@ ogmrip_xvid_dialog_max_bframes_changed (OGMRipXvidDialog *dialog)
 static void
 ogmrip_xvid_dialog_init (OGMRipXvidDialog *dialog)
 {
-  GtkWidget *widget;
+  GtkWidget *area, *widget;
   GladeXML *xml;
 
   xml = glade_xml_new (OGMRIP_DATA_DIR "/" OGMRIP_GLADE_FILE, OGMRIP_GLADE_ROOT, NULL);
@@ -171,8 +171,10 @@ ogmrip_xvid_dialog_init (OGMRipXvidDialog *dialog)
   gtk_window_set_title (GTK_WINDOW (dialog), _("XviD Options"));
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   widget = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), widget);
   gtk_widget_show (widget);
 
   dialog->bquant_offset_spin = glade_xml_get_widget (xml, "bquant_offset-spin");
