@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -85,6 +85,13 @@ struct _OGMRipSubpFile
   gint charset;
 };
 
+typedef struct
+{
+  const gchar *fourcc;
+  guint value;
+  guint format;
+} OGMRipFileConfig;
+
 static gchar **
 ogmrip_backend_identify_command (const gchar *filename, gboolean lavf)
 {
@@ -464,6 +471,30 @@ ogmrip_file_get_language (OGMRipFile *file)
   return file->lang;
 }
 
+OGMRipFileConfig audio_config[] =
+{
+  { "MP3 ", 0x55,    OGMRIP_FORMAT_MP3    },
+  { ".mp3", 0,       OGMRIP_FORMAT_MP3    },
+  { "LAME", 0,       OGMRIP_FORMAT_MP3    },
+  { "mp4a", 0,       OGMRIP_FORMAT_AAC    },
+  { "MP4A", 0,       OGMRIP_FORMAT_AAC    },
+  { "AAC ", 0xff,    OGMRIP_FORMAT_AAC    },
+  { "AAC ", 0x706d,  OGMRIP_FORMAT_AAC    },
+  { "AAC ", 0x4143,  OGMRIP_FORMAT_AAC    },
+  { "AAC ", 0xa106,  OGMRIP_FORMAT_AAC    },
+  { "AACP", 0,       OGMRIP_FORMAT_AAC    },
+  { "vrbs", 0x566f,  OGMRIP_FORMAT_VORBIS },
+  { "dnet", 0,       OGMRIP_FORMAT_AC3    },
+  { "PCM ", 0x01,    OGMRIP_FORMAT_PCM    },
+  { "MP12", 0x50,    OGMRIP_FORMAT_MP12   },
+  { "AC-3", 0x2000,  OGMRIP_FORMAT_AC3    },
+  { "ac-3", 0,       OGMRIP_FORMAT_AC3    },
+  { "DTS ", 0x2001,  OGMRIP_FORMAT_DTS    },
+  { "fLaC", 0xF1AC,  OGMRIP_FORMAT_FLAC   },
+  { "LPCM", 0x10001, OGMRIP_FORMAT_LPCM   },
+  { NULL,   0,       0                    }
+};
+
 /**
  * ogmrip_audio_file_new:
  * @filename: A filename
@@ -480,7 +511,7 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
 
   GError *tmp_error = NULL;
   gboolean result, is_video = FALSE;
-  gint i, rate = -1, bitrate = -1, format = -1, channels = -1;
+  gint i, j, rate = -1, bitrate = -1, format = -1, channels = -1;
   gchar **argv, *output, **lines;
   gdouble length = -1.0;
 
@@ -527,10 +558,32 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
       channels = strtoul (lines[i] + 13, NULL, 10);
     else if (g_str_has_prefix (lines[i], "ID_AUDIO_FORMAT="))
     {
-      if (strncmp (lines[i] + 16, "vrbs", 4) == 0)
-        format = 0x566f;
-      else
-        format = strtoul (lines[i] + 16, NULL, 10);
+      gint fourcc = 0, value;
+
+      if (strlen (lines[i] + 16) == 4)
+      {
+        fourcc  = (lines[i][19] << 24) & 0xff000000;
+        fourcc |= (lines[i][18] << 16) & 0x00ff0000;
+        fourcc |= (lines[i][17] <<  8) & 0x0000ff00;
+        fourcc |= (lines[i][16] <<  0) & 0x000000ff;
+      }
+
+      value = strtoul (lines[i] + 16, NULL, 10);
+
+      for (j = 0; audio_config[j].fourcc; j ++)
+      {
+        if (value && value == audio_config[j].value)
+        {
+          format = audio_config[j].format;
+          break;
+        }
+
+        if (fourcc && g_str_has_prefix (lines[i] + 16, audio_config[j].fourcc))
+        {
+          format = audio_config[j].format;
+          break;
+        }
+      }
     }
     else if (g_str_has_prefix (lines[i], "ID_VIDEO"))
       is_video = TRUE;
@@ -939,6 +992,41 @@ ogmrip_subp_file_get_charset (OGMRipSubpFile *subp)
   return subp->charset;
 }
 
+static const OGMRipFileConfig video_config[] =
+{
+  { "XVID",       0, OGMRIP_FORMAT_MPEG4  },
+  { "xvid",       0, OGMRIP_FORMAT_MPEG4  },
+  { "XviD",       0, OGMRIP_FORMAT_MPEG4  },
+  { "FMP4",       0, OGMRIP_FORMAT_MPEG4  },
+  { "fmp4",       0, OGMRIP_FORMAT_MPEG4  },
+  { "DIVX",       0, OGMRIP_FORMAT_MPEG4  },
+  { "divx",       0, OGMRIP_FORMAT_MPEG4  },
+  { "DX50",       0, OGMRIP_FORMAT_MPEG4  },
+  { "dx50",       0, OGMRIP_FORMAT_MPEG4  },
+  { "MP4V",       0, OGMRIP_FORMAT_MPEG4  },
+  { "mp4v",       0, OGMRIP_FORMAT_MPEG4  },
+  { "h264",       0, OGMRIP_FORMAT_H264   },
+  { "H264",       0, OGMRIP_FORMAT_H264   },
+  { "x264",       0, OGMRIP_FORMAT_H264   },
+  { "X264",       0, OGMRIP_FORMAT_H264   },
+  { "avc1",       0, OGMRIP_FORMAT_H264   },
+  { "AVC1",       0, OGMRIP_FORMAT_H264   },
+  { "davc",       0, OGMRIP_FORMAT_H264   },
+  { "DAVC",       0, OGMRIP_FORMAT_H264   },
+  { "theo",       0, OGMRIP_FORMAT_THEORA },
+  { "Thra",       0, OGMRIP_FORMAT_THEORA },
+  { "MJPG",       0, OGMRIP_FORMAT_MJPEG  },
+  { "mpg1",       0, OGMRIP_FORMAT_MPEG1  },
+  { "MPG1",       0, OGMRIP_FORMAT_MPEG1  },
+  { "0x10000001", 0, OGMRIP_FORMAT_MPEG1  },
+  { "mpg2",       0, OGMRIP_FORMAT_MPEG2  },
+  { "MPG2",       0, OGMRIP_FORMAT_MPEG2  },
+  { "0x10000002", 0, OGMRIP_FORMAT_MPEG2  },
+  { "drac",       0, OGMRIP_FORMAT_DIRAC  },
+  { "VP80",       0, OGMRIP_FORMAT_VP8    },
+  { NULL,         0, 0                    }
+};
+
 /**
  * ogmrip_video_file_new:
  * @filename: A filename
@@ -954,7 +1042,7 @@ ogmrip_video_file_new (const gchar *filename, GError **error)
   OGMRipVideoFile *video;
 
   GError *tmp_error = NULL;
-  gint i, bitrate = -1, format = -1, width = -1, height = -1;
+  gint i, j, bitrate = -1, format = -1, width = -1, height = -1;
   gdouble fps = -1.0, aspect = -1.0, length = -1.0;
   gchar **argv, *output, **lines;
   gboolean result;
@@ -1006,18 +1094,14 @@ ogmrip_video_file_new (const gchar *filename, GError **error)
       aspect = strtod (lines[i] + 16, NULL);
     else if (g_str_has_prefix (lines[i], "ID_VIDEO_FORMAT="))
     {
-      if (strncmp (lines[i] + 16, "XVID", 4) == 0)
-        format = OGMRIP_FORMAT_MPEG4;
-      else if (strncmp (lines[i] + 16, "FMP4", 4) == 0)
-        format = OGMRIP_FORMAT_MPEG4;
-      else if (strncmp (lines[i] + 16, "h264", 4) == 0)
-        format = OGMRIP_FORMAT_H264;
-      else if (strncmp (lines[i] + 16, "theo", 4) == 0)
-        format = OGMRIP_FORMAT_THEORA;
-      else if (strncmp (lines[i] + 16, "0x10000001", 10) == 0)
-        format = OGMRIP_FORMAT_MPEG1;
-      else if (strncmp (lines[i] + 16, "0x10000002", 10) == 0)
-        format = OGMRIP_FORMAT_MPEG2;
+      for (j = 0; video_config[j].fourcc; j ++)
+      {
+        if (g_str_has_prefix (lines[i] + 16, video_config[j].fourcc))
+        {
+          format = video_config[j].format;
+          break;
+        }
+      }
     }
 
     if (errno != 0)
