@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -485,6 +485,9 @@ static gint formats[] =
   OGMRIP_FORMAT_SRT,
   OGMRIP_FORMAT_VOBSUB,
   OGMRIP_FORMAT_SSA,
+  OGMRIP_FORMAT_FLAC,
+  -1,
+  -1,
   -1
 };
 
@@ -492,6 +495,7 @@ OGMRipContainerPlugin *
 ogmrip_init_plugin (GError **error)
 {
   gchar *output;
+  guint i = 0;
 
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
@@ -513,6 +517,23 @@ ogmrip_init_plugin (GError **error)
 
   g_free (output);
 
+  if (!g_spawn_command_line_sync ("mkvmerge --list-types", &output, NULL, NULL, NULL))
+  {
+    g_set_error (error, OGMRIP_PLUGIN_ERROR, OGMRIP_PLUGIN_ERROR_REQ, _("mkvmerge is missing"));
+    return NULL;
+  }
+
+  while (formats[i] != -1)
+    i++;
+
+  if (strstr (output, " drc ") || strstr (output, " Dirac "))
+    formats[i++] = OGMRIP_FORMAT_DIRAC;
+
+  if (strstr (output, " ivf ") || strstr (output, " IVF "))
+    formats[i++] = OGMRIP_FORMAT_VP8;
+
+  g_free (output);
+
   mkv_plugin.type = OGMRIP_TYPE_MATROSKA;
   mkv_plugin.formats = formats;
 
