@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -97,7 +97,6 @@ ogmrip_mp3_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input
   if (!header)
   {
     g_ptr_array_add (argv, g_strdup ("-r"));
-    g_ptr_array_add (argv, g_strdup ("-x"));
     g_ptr_array_add (argv, g_strdup ("-s"));
     g_ptr_array_add (argv, g_strdup_printf ("%.1f",
           ogmrip_audio_codec_get_sample_rate (audio) / 1000.0));
@@ -166,7 +165,7 @@ ogmrip_mp3_run (OGMJobSpawn *spawn)
   ogmjob_container_add (OGMJOB_CONTAINER (spawn), pipeline);
   g_object_unref (pipeline);
 
-  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, NULL, fifo);
+  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), FALSE, NULL, fifo);
   if (argv)
   {
     child = ogmjob_exec_newv (argv);
@@ -175,7 +174,7 @@ ogmrip_mp3_run (OGMJobSpawn *spawn)
     ogmjob_container_add (OGMJOB_CONTAINER (pipeline), child);
     g_object_unref (child);
 
-    argv = ogmrip_mp3_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, fifo, NULL);
+    argv = ogmrip_mp3_command (OGMRIP_AUDIO_CODEC (spawn), FALSE, fifo, NULL);
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
