@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,9 @@
 #include "ogmjob-exec.h"
 #include "ogmjob-queue.h"
 
+#include <errno.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
@@ -288,6 +290,10 @@ ogmrip_mencoder_extract_command (OGMRipVideoCodec *video, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("0"));
 
   g_ptr_array_add (argv, g_strdup ("-nosound"));
+
+  if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
+
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("copy"));
 
@@ -679,7 +685,7 @@ OGMRipContainerPlugin *
 ogmrip_init_plugin (GError **error)
 {
   gchar *output;
-  gboolean match;
+  gint major_version = 0, minor_version = 0, micro_version = 0;
 
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
@@ -689,10 +695,22 @@ ogmrip_init_plugin (GError **error)
     return NULL;
   }
 
-  match = g_str_has_prefix (output, "MP4Box - GPAC version 0.4.5");
+  if (g_str_has_prefix (output, "MP4Box - GPAC version "))
+  {
+    gchar *end;
+
+    errno = 0;
+    major_version = strtoul (output + 22, &end, 10);
+    if (!errno && *end == '.')
+      minor_version = strtoul (end + 1, NULL, 10);
+    if (!errno && *end == '.')
+      micro_version = strtoul (end + 1, NULL, 10);
+  }
   g_free (output);
 
-  if (match)
+  if ((major_version > 0) ||
+      (major_version == 0 && minor_version > 4) ||
+      (major_version == 0 && minor_version == 4 && micro_version >= 5))
   {
     guint i = 0;
 
