@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@
 
 #include <glib/gstdio.h>
 
-static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif=0" };
+static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif" };
 
 static gint
 ogmrip_mplayer_map_audio_id (OGMDvdAudioStream *astream)
@@ -128,6 +128,66 @@ ogmrip_mplayer_get_chapters (OGMRipCodec *codec, OGMDvdTitle *title)
   return NULL;
 }
 
+static gboolean
+ogmrip_mplayer_check_mcdeint (void)
+{
+  static gint have_mcdeint = -1;
+
+  if (have_mcdeint < 0) 
+  {
+    gchar *output = NULL;
+
+    have_mcdeint = 0;
+    if (g_spawn_command_line_sync ("mplayer -vf help", &output, NULL, NULL, NULL))
+    {
+      if (output && strstr (output, "mcdeint"))
+        have_mcdeint = 1;
+      g_free (output);
+    }
+  }
+
+  return have_mcdeint == 1;
+}
+
+static void
+ogmrip_mplayer_set_deint (OGMRipVideoCodec *video, GPtrArray *argv, GString *options, GString *pp)
+{
+  OGMRipDeintType deint;
+
+  deint = ogmrip_video_codec_get_deinterlacer (video);
+  if (deint != OGMRIP_DEINT_NONE)
+  {
+    if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
+    {
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append (options, deinterlacer[deint - 1]);
+
+      if (deint == OGMRIP_DEINT_YADIF)
+      {
+        if (MPLAYER_CHECK_VERSION (1,0,2,0))
+        {
+          g_string_append (options, "=3");
+
+          if (ogmrip_mplayer_check_mcdeint ())
+            g_string_append (options, ",mcdeint=2:1:10");
+
+          g_ptr_array_add (argv, g_strdup ("-field-dominance"));
+          g_ptr_array_add (argv, g_strdup ("-1")); /* or 1 ? */
+        }
+        else
+          g_string_append (options, "=0");
+      }
+    }
+    else
+    {
+      if (pp->len > 0)
+        g_string_append_c (pp, '/');
+      g_string_append (pp, deinterlacer[deint - 1]);
+    }
+  }
+}
+
 static void
 ogmrip_mplayer_append_edl (OGMRipCodec *codec, GPtrArray *argv, gboolean hr)
 {
@@ -453,7 +513,7 @@ ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
   GPtrArray *argv;
   const gchar *device;
   gdouble start, length;
-  gchar *chap;
+  gchar *ofps, *chap;
   gint vid;
 
   OGMDvdTitle *title;
@@ -474,6 +534,13 @@ ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
+  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
+  if (ofps)
+  {
+    g_ptr_array_add (argv, g_strdup ("-ofps"));
+    g_ptr_array_add (argv, ofps);
+  }
+
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (audio), title);
   if (chap)
   {
@@ -564,7 +631,6 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
     OGMDvdAudioStream *astream;
     OGMDvdSubpStream *sstream;
     OGMRipScalerType scaler;
-    OGMRipDeintType deint;
 
     GString *options, *pp;
     guint max_width, max_height;
@@ -599,6 +665,8 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
       if (forced)
         g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
     }
+    else if (ogmrip_check_mplayer_nosub ())
+      g_ptr_array_add (argv, g_strdup ("-nosub"));
 
     scaler = ogmrip_video_codec_get_scaler (video);
     g_ptr_array_add (argv, g_strdup ("-sws"));
@@ -638,22 +706,7 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
       g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
     }
 
-    deint = ogmrip_video_codec_get_deinterlacer (video);
-    if (deint != OGMRIP_DEINT_NONE)
-    {
-      if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
-      {
-        if (options->len > 0)
-          g_string_append_c (options, ',');
-        g_string_append (options, deinterlacer[deint - 1]);
-      }
-      else
-      {
-        if (pp->len > 0)
-          g_string_append_c (pp, '/');
-        g_string_append (pp, deinterlacer[deint - 1]);
-      }
-    }
+    ogmrip_mplayer_set_deint (video, argv, options, pp);
 
     if (pp->len > 0)
     {
@@ -668,6 +721,9 @@ ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, gui
       if (options->len > 0)
         g_string_append_c (options, ',');
       g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
+
+      if (ogmrip_video_codec_is_interlaced (video) > 0 && ogmrip_video_codec_get_deinterlacer (video) == OGMRIP_DEINT_NONE)
+        g_string_append (options, ":1");
     }
 
     if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
@@ -782,12 +838,13 @@ GPtrArray *
 ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 {
   OGMDvdTitle *title;
+  OGMDvdSubpStream *sstream;
   GPtrArray *argv;
 
   gint format;
   const gchar *device;
   gdouble start, length;
-  gboolean scale;
+  gboolean forced, scale;
   gchar *chap;
 
   g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
@@ -815,12 +872,26 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
     g_ptr_array_add (argv, g_strdup ("all"));
   }
 
+  sstream = ogmrip_video_codec_get_hard_subp (video, &forced);
+  if (sstream)
+  {
+    g_ptr_array_add (argv, g_strdup ("-spuaa"));
+    g_ptr_array_add (argv, g_strdup ("20"));
+    g_ptr_array_add (argv, g_strdup ("-sid"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d",
+          ogmdvd_stream_get_id (OGMDVD_STREAM (sstream))));
+
+    if (forced)
+      g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
+  }
+  else if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
+
   scale = FALSE;
 
   if (format != OGMRIP_FORMAT_COPY)
   {
     OGMRipScalerType scaler;
-    OGMRipDeintType deint;
 
     GString *options, *pp;
     guint max_width, max_height;
@@ -866,22 +937,7 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
       g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
     }
 
-    deint = ogmrip_video_codec_get_deinterlacer (video);
-    if (deint != OGMRIP_DEINT_NONE)
-    {
-      if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
-      {
-        if (options->len > 0)
-          g_string_append_c (options, ',');
-        g_string_append (options, deinterlacer[deint - 1]);
-      }
-      else
-      {
-        if (pp->len > 0)
-          g_string_append_c (pp, '/');
-        g_string_append (pp, deinterlacer[deint - 1]);
-      }
-    }
+    ogmrip_mplayer_set_deint (video, argv, options, pp);
 
     if (pp->len > 0)
     {
@@ -896,6 +952,9 @@ ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
       if (options->len > 0)
         g_string_append_c (options, ',');
       g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
+
+      if (ogmrip_video_codec_is_interlaced (video) > 0 && ogmrip_video_codec_get_deinterlacer (video) == OGMRIP_DEINT_NONE)
+        g_string_append (options, ":1");
     }
 
     if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
@@ -1009,8 +1068,8 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   GPtrArray *argv;
   gdouble start, length;
   const gchar *device;
+  gchar *ofps, *chap;
   gint vid, sid;
-  gchar *chap;
 
   g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
 
@@ -1044,6 +1103,13 @@ ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("copy"));
 
+  ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (subp), title);
+  if (ofps)
+  {
+    g_ptr_array_add (argv, g_strdup ("-ofps"));
+    g_ptr_array_add (argv, ofps);
+  }
+
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup ("/dev/null"));
 
