@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -150,6 +150,8 @@ ogmrip_mplayer_play_command (OGMRipPlayer *player)
     g_ptr_array_add (argv, g_strdup_printf ("%d",
           ogmdvd_stream_get_id (OGMDVD_STREAM (player->priv->sstream))));
   }
+  else if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
 
   if (player->priv->start_chap > 0 || player->priv->end_chap >= 0)
   {
