@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -82,6 +82,7 @@ struct _OGMRipVideoCodecPriv
   OGMJobSpawn *child;
   gboolean child_canceled;
   gboolean forced_subs;
+  gint interlaced;
 };
 
 typedef struct
@@ -354,6 +355,9 @@ ogmrip_video_codec_crop_command (OGMRipVideoCodec *video, gdouble start, gulong
   g_ptr_array_add (argv, g_strdup ("-nosound"));
   g_ptr_array_add (argv, g_strdup ("-nocache"));
 
+  if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
+
   if (MPLAYER_CHECK_VERSION (1,0,3,0))
   {
     g_ptr_array_add (argv, g_strdup ("-noconfig"));
@@ -431,6 +435,9 @@ ogmrip_video_codec_analyze_command (OGMRipVideoCodec *video, gulong nframes)
   g_ptr_array_add (argv, g_strdup ("-nosound"));
   g_ptr_array_add (argv, g_strdup ("-nocache"));
 
+  if (ogmrip_check_mplayer_nosub ())
+    g_ptr_array_add (argv, g_strdup ("-nosub"));
+
   if (MPLAYER_CHECK_VERSION (1,0,3,0))
   {
     g_ptr_array_add (argv, g_strdup ("-noconfig"));
@@ -570,6 +577,7 @@ ogmrip_video_codec_init (OGMRipVideoCodec *video)
   video->priv->angle = 1;
   video->priv->bpp = 0.25;
   video->priv->passes = 1;
+  video->priv->interlaced = -1;
 }
 
 static void
@@ -723,8 +731,10 @@ ogmrip_video_codec_autosize (OGMRipVideoCodec *video)
   guint min_width, min_height;
   gboolean expand;
 
-  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) ||
-      ogmrip_video_codec_get_min_size (video, &min_width, &min_height))
+  ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand);
+  ogmrip_video_codec_get_min_size (video, &min_width, &min_height);
+
+  if ((max_width && max_height) || (min_width || min_height))
   {
     guint scale_width, scale_height;
 
@@ -745,13 +755,13 @@ ogmrip_video_codec_autosize (OGMRipVideoCodec *video)
         scale_width = FLOOR (scale_height * ratio);
       }
 
-      if (scale_width > min_width)
+      if (scale_width < min_width)
       {
         scale_width = min_width;
         scale_height = ROUND (scale_width / ratio);
       }
 
-      if (scale_height > min_height)
+      if (scale_height < min_height)
       {
         scale_height = min_height;
         scale_width = ROUND (scale_height * ratio);
@@ -1061,7 +1071,8 @@ ogmrip_video_codec_set_deinterlacer (OGMRipVideoCodec *video, OGMRipDeintType de
 {
   g_return_if_fail (OGMRIP_IS_VIDEO_CODEC (video));
 
-  video->priv->deint = deint;
+  if (video->priv->interlaced != 0)
+    video->priv->deint = deint;
 }
 
 /**
@@ -1588,10 +1599,10 @@ ogmrip_video_codec_get_scale_size (OGMRipVideoCodec *video, guint *width, guint
     scale_height = raw_height;
 
   if (width)
-    *width = scale_width;
+    *width = 16 * ROUND (scale_width / 16.0);
 
   if (height)
-    *height = scale_height;
+    *height = 16 * ROUND (scale_height / 16.0);
 
   return scale_width != raw_width || scale_height != raw_height;
 }
@@ -1792,7 +1803,7 @@ ogmrip_video_codec_autoscale (OGMRipVideoCodec *video)
     scale_height = raw_height;
     for (scale_width = raw_width - 25 * 16; scale_width <= raw_width; scale_width += 16)
     {
-      scale_height = 16 * ROUND (scale_width / ratio / 16);
+      scale_height = ROUND (scale_width / ratio);
 
       bpp = (video->priv->bitrate * rdenominator) / 
         (gdouble) (scale_width * scale_height * rnumerator);
@@ -1803,8 +1814,8 @@ ogmrip_video_codec_autoscale (OGMRipVideoCodec *video)
   }
   else
   {
-    scale_width = raw_width;
-    scale_height = 16 * ROUND (scale_width / ratio / 16);
+    scale_width = crop_width;
+    scale_height = ROUND (scale_width / ratio);
   }
 
   scale_width = MIN (scale_width, raw_width);
@@ -1966,8 +1977,10 @@ ogmrip_video_codec_analyze (OGMRipVideoCodec *video, guint nframes)
   if (video->priv->child_canceled)
     return FALSE;
 
+  video->priv->interlaced = analyze.content && !analyze.telecine ? 1 : 0;
+
   ogmrip_video_codec_set_deinterlacer (video,
-      analyze.content && !analyze.telecine ? OGMRIP_DEINT_YADIF: OGMRIP_DEINT_NONE);
+      video->priv->interlaced ? OGMRIP_DEINT_YADIF: OGMRIP_DEINT_NONE);
   ogmrip_codec_set_telecine (OGMRIP_CODEC (video), analyze.content && analyze.telecine);
   ogmrip_codec_set_progressive (OGMRIP_CODEC (video), analyze.progressive);
 
@@ -2020,3 +2033,19 @@ ogmrip_video_codec_set_hard_subp (OGMRipVideoCodec *video, OGMDvdSubpStream *str
   }
 }
 
+/**
+ * ogmrip_video_codec_is_interlaced:
+ * @video: an #OGMRipVideoCodec
+ *
+ * Gets whether the video stream is interlaced.
+ *
+ * Returns: 1 if the video interlaced, 0 if it isn't, -1 otherwise.
+ */
+gint
+ogmrip_video_codec_is_interlaced (OGMRipVideoCodec  *video)
+{
+  g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), -1);
+
+  return video->priv->interlaced;
+}
+
