@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -198,19 +198,21 @@ static const gchar *cqm_name[] =
   "flat", "jvm"
 };
 
-gboolean x264_have_8x8dct     = FALSE;
-gboolean x264_have_aud        = FALSE;
-gboolean x264_have_bime       = FALSE;
-gboolean x264_have_b_pyramid  = FALSE;
-gboolean x264_have_brdo       = FALSE;
-gboolean x264_have_lookahead  = FALSE;
-gboolean x264_have_me         = FALSE;
-gboolean x264_have_me_tesa    = FALSE;
-gboolean x264_have_mixed_refs = FALSE;
-gboolean x264_have_partitions = FALSE;
-gboolean x264_have_psy        = FALSE;
-gboolean x264_have_turbo      = FALSE;
-gboolean x264_have_weight_p  = FALSE;
+gboolean x264_have_8x8dct         = FALSE;
+gboolean x264_have_aud            = FALSE;
+gboolean x264_have_bime           = FALSE;
+gboolean x264_have_b_pyramid      = FALSE;
+gboolean x264_have_brdo           = FALSE;
+gboolean x264_have_lookahead      = FALSE;
+gboolean x264_have_me             = FALSE;
+gboolean x264_have_me_tesa        = FALSE;
+gboolean x264_have_mixed_refs     = FALSE;
+gboolean x264_have_partitions     = FALSE;
+gboolean x264_have_psy            = FALSE;
+gboolean x264_have_turbo          = FALSE;
+gboolean x264_have_weight_p       = FALSE;
+gboolean x264_have_slow_firstpass = FALSE;
+gboolean x264_have_nombtree       = FALSE;
 
 static gint
 ogmrip_x264_get_crf (OGMRipVideoCodec *video, gdouble quantizer)
@@ -264,7 +266,7 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   g_string_append_printf (options, ":frameref=%u", cartoon ? x264->frameref * 2 : x264->frameref);
   g_string_append_printf (options, ":b_adapt=%u", x264->b_adapt);
 
-  if (passes > 1)
+  if (passes > 1 && x264_have_nombtree)
     g_string_append (options, ":nombtree");
 
   if (x264_have_me)
@@ -288,12 +290,15 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   bframes = ogmrip_video_codec_get_max_b_frames (video);
   g_string_append_printf (options, ":bframes=%d", cartoon ? bframes + 2 : bframes);
 
-  if (x264_have_turbo && pass != passes)
+  if (pass != passes)
   {
-    if (ogmrip_video_codec_get_turbo (video))
-      g_string_append (options, ":turbo=2");
-    else
-      g_string_append (options, ":turbo=1");
+    gboolean turbo;
+
+    turbo = ogmrip_video_codec_get_turbo (video);
+    if (x264_have_slow_firstpass && !turbo)
+      g_string_append (options, ":slow_firstpass");
+    else if (x264_have_turbo)
+      g_string_append (options, turbo ? ":turbo=2" : ":turbo=1");
   }
 
   trellis = ogmrip_video_codec_get_trellis (video);
@@ -374,7 +379,7 @@ ogmrip_x264_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
 
   if (passes > 1 && log_file)
   {
-    g_string_append_printf (options, ":pass=%u", pass == 1 ? 1 : passes == 2 ? 2 : 3);
+    g_string_append_printf (options, ":pass=%u", pass == 1 ? 1 : pass == passes ? 2 : 3);
 
     g_ptr_array_add (argv, g_strdup ("-passlogfile"));
     g_ptr_array_add (argv, g_strdup (log_file));
@@ -835,7 +840,7 @@ static gboolean
 ogmrip_x264_check_option (const gchar *option)
 {
   GPtrArray *argv;
-  gchar *options;
+  gchar *options, *output = NULL;
   gint status;
 
   argv = g_ptr_array_new ();
@@ -843,9 +848,9 @@ ogmrip_x264_check_option (const gchar *option)
   g_ptr_array_add (argv, "mencoder");
   g_ptr_array_add (argv, "-nocache");
   g_ptr_array_add (argv, "-nosound");
-  g_ptr_array_add (argv, "-really-quiet");
+  g_ptr_array_add (argv, "-quiet");
   g_ptr_array_add (argv, "-frames");
-  g_ptr_array_add (argv, "0");
+  g_ptr_array_add (argv, "1");
   g_ptr_array_add (argv, "-rawvideo");
   g_ptr_array_add (argv, "pal:fps=25");
   g_ptr_array_add (argv, "-demuxer");
@@ -863,13 +868,26 @@ ogmrip_x264_check_option (const gchar *option)
   g_ptr_array_add (argv, NULL);
 
   g_spawn_sync (NULL, (gchar **) argv->pdata, NULL,
-      G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
-      NULL, NULL, NULL, NULL, &status, NULL);
+      G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL,
+      NULL, NULL, NULL, &output, &status, NULL);
   
   g_ptr_array_free (argv, TRUE);
 
   g_free (options);
 
+  if (status == 0 && output != NULL)
+  {
+    gchar *substr;
+
+    substr = g_strdup_printf ("Option x264encopts: Unknown suboption %s", option);
+    if (strstr (output, substr))
+      status = 1;
+    g_free (substr);
+  }
+
+  if (output)
+    g_free (output);
+
   return status == 0;
 }
 
@@ -921,19 +939,21 @@ ogmrip_init_plugin (GError **error)
     return NULL;
   }
 
-  x264_have_8x8dct     = ogmrip_x264_check_option ("8x8dct");
-  x264_have_aud        = ogmrip_x264_check_option ("aud");
-  x264_have_bime       = ogmrip_x264_check_option ("bime");
-  x264_have_b_pyramid  = ogmrip_x264_check_option ("b_pyramid=none");
-  x264_have_brdo       = ogmrip_x264_check_option ("brdo");
-  x264_have_lookahead  = ogmrip_x264_check_option ("rc_lookahead=40");
-  x264_have_me         = ogmrip_x264_check_option ("me=hex");
-  x264_have_me_tesa    = ogmrip_x264_check_option ("me=tesa");
-  x264_have_mixed_refs = ogmrip_x264_check_option ("mixed_refs");
-  x264_have_partitions = ogmrip_x264_check_option ("partitions=all");
-  x264_have_psy        = ogmrip_x264_check_option ("psy-rd=1,1");
-  x264_have_turbo      = ogmrip_x264_check_option ("turbo=2");
-  x264_have_weight_p   = ogmrip_x264_check_option ("weightp=2");
+  x264_have_8x8dct         = ogmrip_x264_check_option ("8x8dct");
+  x264_have_aud            = ogmrip_x264_check_option ("aud");
+  x264_have_bime           = ogmrip_x264_check_option ("bime");
+  x264_have_b_pyramid      = ogmrip_x264_check_option ("b_pyramid=none");
+  x264_have_brdo           = ogmrip_x264_check_option ("brdo");
+  x264_have_lookahead      = ogmrip_x264_check_option ("rc_lookahead=40");
+  x264_have_me             = ogmrip_x264_check_option ("me=hex");
+  x264_have_me_tesa        = ogmrip_x264_check_option ("me=tesa");
+  x264_have_mixed_refs     = ogmrip_x264_check_option ("mixed_refs");
+  x264_have_partitions     = ogmrip_x264_check_option ("partitions=all");
+  x264_have_psy            = ogmrip_x264_check_option ("psy-rd=1,1");
+  x264_have_turbo          = ogmrip_x264_check_option ("turbo=2");
+  x264_have_weight_p       = ogmrip_x264_check_option ("weightp=2");
+  x264_have_slow_firstpass = ogmrip_x264_check_option ("slow_firstpass");
+  x264_have_nombtree       = ogmrip_x264_check_option ("nombtree");
 
   settings = ogmrip_settings_get_default ();
   if (settings)
