@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -175,7 +175,7 @@ ogmrip_xvid_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
   GString *options;
 
   const char *output;
-  gint quality, bitrate, vid, threads, bframes;
+  gint quality, bitrate, vid, threads, bframes, interlaced;
 
   static const gchar *profiles[] =
   {
@@ -252,7 +252,11 @@ ogmrip_xvid_command (OGMRipVideoCodec *video, guint pass, guint passes, const gc
     else
       g_string_append (options, ":nogmc");
 
-    if (xvid->interlacing)
+    interlaced = ogmrip_video_codec_is_interlaced (video);
+    if (interlaced > 0 && ogmrip_video_codec_get_deinterlacer (video) != OGMRIP_DEINT_NONE)
+      interlaced = 0;
+
+    if (interlaced > 0 || xvid->interlacing)
       g_string_append (options, ":interlacing");
     else
       g_string_append (options, ":nointerlacing");
@@ -851,7 +855,7 @@ static gboolean
 ogmrip_xvid_check_option (const gchar *option)
 {
   GPtrArray *argv;
-  gchar *options;
+  gchar *options, *output = NULL;
   gint status;
 
   argv = g_ptr_array_new ();
@@ -859,9 +863,9 @@ ogmrip_xvid_check_option (const gchar *option)
   g_ptr_array_add (argv, "mencoder");
   g_ptr_array_add (argv, "-nocache");
   g_ptr_array_add (argv, "-nosound");
-  g_ptr_array_add (argv, "-really-quiet");
+  g_ptr_array_add (argv, "-quiet");
   g_ptr_array_add (argv, "-frames");
-  g_ptr_array_add (argv, "0");
+  g_ptr_array_add (argv, "1");
   g_ptr_array_add (argv, "-rawvideo");
   g_ptr_array_add (argv, "pal:fps=25");
   g_ptr_array_add (argv, "-demuxer");
@@ -879,13 +883,26 @@ ogmrip_xvid_check_option (const gchar *option)
   g_ptr_array_add (argv, NULL);
 
   g_spawn_sync (NULL, (gchar **) argv->pdata, NULL,
-      G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
-      NULL, NULL, NULL, NULL, &status, NULL);
+      G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL,
+      NULL, NULL, NULL, &output, &status, NULL);
 
   g_ptr_array_free (argv, TRUE);
 
   g_free (options);
 
+  if (status == 0 && output != NULL)
+  {
+    gchar *substr;
+
+    substr = g_strdup_printf ("Option xvidencopts: Unknown suboption %s", option);
+    if (strstr (output, substr))
+      status = 1;
+    g_free (substr);
+  }
+
+  if (output)
+    g_free (output);
+
   return status == 0;
 }
 
