@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -75,6 +75,9 @@ struct _OGMRipProfileEditorDialogPriv
   GtkWidget *video_options_label;
   GtkWidget *video_options_vbox;
 
+  GtkWidget *audio_quality_label;
+  GtkWidget *audio_quality_spin;
+
   GtkWidget *audio_options_label;
   GtkWidget *audio_options_table;
 
@@ -339,15 +342,25 @@ ogmrip_profile_editor_dialog_check_audio_codec (OGMRipSettings *settings,
 {
   GType codec;
   const gchar *name = NULL;
+  gint format;
 
   if (value && G_IS_VALUE (value))
     name = g_value_get_string (value);
   codec = ogmrip_profile_editor_dialog_get_audio_codec_type (dialog, name);
 
+  format = ogmrip_plugin_get_audio_codec_format (codec);
+
   gtk_widget_set_sensitive (dialog->priv->audio_options_label,
-      codec != G_TYPE_NONE && ogmrip_plugin_get_audio_codec_format (codec) != OGMRIP_FORMAT_COPY);
+      codec != G_TYPE_NONE && format != OGMRIP_FORMAT_COPY);
   gtk_widget_set_sensitive (dialog->priv->audio_options_table,
-      codec != G_TYPE_NONE && ogmrip_plugin_get_audio_codec_format (codec) != OGMRIP_FORMAT_COPY);
+      codec != G_TYPE_NONE && format != OGMRIP_FORMAT_COPY);
+
+  gtk_widget_set_sensitive (dialog->priv->audio_quality_label,
+      codec != G_TYPE_NONE && format != OGMRIP_FORMAT_COPY &&
+      format != OGMRIP_FORMAT_PCM && format != OGMRIP_FORMAT_BPCM && format != OGMRIP_FORMAT_LPCM);
+  gtk_widget_set_sensitive (dialog->priv->audio_quality_spin,
+      codec != G_TYPE_NONE && format != OGMRIP_FORMAT_COPY &&
+      format != OGMRIP_FORMAT_PCM && format != OGMRIP_FORMAT_BPCM && format != OGMRIP_FORMAT_LPCM);
 }
 
 /*
@@ -721,15 +734,17 @@ ogmrip_profile_editor_dialog_class_init (OGMRipProfileEditorDialogClass *klass)
 static void
 ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
 {
-  GtkWidget *widget;
+  GtkWidget *area, *widget;
   GladeXML *xml;
 
   dialog->priv = OGMRIP_PROFILE_EDITOR_DIALOG_GET_PRIVATE (dialog);
 
   dialog->priv->profile_section = g_strdup (_profile_section);
 
+  area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+
   widget = gtk_button_new_with_mnemonic (_("_Reset"));
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), widget);
+  gtk_container_add (GTK_CONTAINER (area), widget);
   gtk_widget_show (widget);
 
   g_signal_connect_swapped (widget, "clicked",
@@ -767,11 +782,13 @@ ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
   g_signal_connect_swapped (dialog->priv->subp_options_button, "clicked",
       G_CALLBACK (ogmrip_profile_editor_dialog_subp_options_button_clicked), dialog);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   if (dialog->priv->root)
-    gtk_container_remove (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), dialog->priv->root);
+    gtk_container_remove (GTK_CONTAINER (area), dialog->priv->root);
 
   dialog->priv->root = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->priv->root, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), dialog->priv->root);
   gtk_widget_show (dialog->priv->root);
 
   /*
@@ -931,7 +948,8 @@ ogmrip_profile_editor_dialog_init (OGMRipProfileEditorDialog *dialog)
       (OGMRipSetFunc) ogmrip_profile_editor_dialog_audio_codec_set_value,
       dialog->priv->profile_section);
 
-  widget = glade_xml_get_widget (xml, "quality-spin");
+  dialog->priv->audio_quality_label = glade_xml_get_widget (xml, "audio-quality-label");
+  dialog->priv->audio_quality_spin = glade_xml_get_widget (xml, "audio-quality-spin");
   ogmrip_settings_bind (settings, dialog->priv->profile_section,
       OGMRIP_GCONF_AUDIO_QUALITY, G_OBJECT (widget), "value");
 
