@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ ogmrip_profiles_dialog_profile_name_changed (GtkTextBuffer *buffer, GtkWidget *d
 static gchar *
 ogmrip_profiles_dialog_run_profile_dialog (GtkWindow *parent, const gchar *old_name)
 {
-  GtkWidget *dialog, *vbox, *label, *frame, *entry;
+  GtkWidget *dialog, *area, *vbox, *label, *frame, *entry;
   GtkTextBuffer *buffer;
 
   gchar *new_name = NULL;
@@ -208,9 +208,11 @@ ogmrip_profiles_dialog_run_profile_dialog (GtkWindow *parent, const gchar *old_n
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
   gtk_window_set_parent (GTK_WINDOW (dialog), parent);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
+  gtk_container_add (GTK_CONTAINER (area), vbox);
   gtk_widget_show (vbox);
 
   label = gtk_label_new (_("_Profile name:"));
@@ -649,7 +651,7 @@ ogmrip_profiles_dialog_class_init (OGMRipProfilesDialogClass *klass)
 static void
 ogmrip_profiles_dialog_init (OGMRipProfilesDialog *dialog)
 {
-  GtkWidget *widget;
+  GtkWidget *area, *widget, *image;
   GtkTreeSelection *selection;
   GladeXML *xml;
 
@@ -671,8 +673,10 @@ ogmrip_profiles_dialog_init (OGMRipProfilesDialog *dialog)
   gtk_window_set_title (GTK_WINDOW (dialog), _("Edit Profiles"));
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PREFERENCES);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   widget = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), widget);
   gtk_widget_show (widget);
 
   dialog->priv->edit_button = glade_xml_get_widget (xml, "edit-button");
@@ -699,15 +703,24 @@ ogmrip_profiles_dialog_init (OGMRipProfilesDialog *dialog)
   g_signal_connect_swapped (dialog->priv->rename_button, "clicked",
       G_CALLBACK (ogmrip_profiles_dialog_rename_button_clicked), dialog);
 
+  image = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->rename_button), image);
+
   dialog->priv->export_button = glade_xml_get_widget (xml, "export-button");
   gtk_widget_set_sensitive (dialog->priv->export_button, FALSE);
   g_signal_connect_swapped (dialog->priv->export_button, "clicked",
       G_CALLBACK (ogmrip_profiles_dialog_export_button_clicked), dialog);
 
+  image = gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->export_button), image);
+
   widget = glade_xml_get_widget (xml, "import-button");
   g_signal_connect_swapped (widget, "clicked",
       G_CALLBACK (ogmrip_profiles_dialog_import_button_clicked), dialog);
 
+  image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (widget), image);
+
   dialog->priv->list = glade_xml_get_widget (xml, "treeview");
   ogmrip_profiles_dialog_construct_profiles (dialog);
 
@@ -735,24 +748,12 @@ ogmrip_profiles_dialog_set_active (OGMRipProfilesDialog *dialog, const gchar *pr
   g_return_if_fail (OGMRIP_IS_PROFILES_DIALOG (dialog));
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->priv->list));
-  if (gtk_tree_model_get_iter_first (model, &iter))
+
+  if (ogmrip_profiles_dialog_find_profile (model, &iter, profile) ||
+      gtk_tree_model_get_iter_first (model, &iter))
   {
     GtkTreeSelection *selection;
 
-    if (profile)
-    {
-      gchar *section;
-      gboolean found;
-
-      do
-      {
-        gtk_tree_model_get (model, &iter, COL_SECTION, &section, -1);
-        found = section != NULL && g_str_equal (section, profile);
-        g_free (section);
-      }
-      while (!found && gtk_tree_model_iter_next (model, &iter));
-    }
-
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->priv->list));
     gtk_tree_selection_select_iter (selection, &iter);
   }
