@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ ogmrip_progress_dialog_get_visibility (OGMRipProgressDialog *dialog)
   if (dialog->priv->iconified)
     return FALSE;
 
-  state = gdk_window_get_state (GTK_WIDGET (dialog)->window);
+  state = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (dialog)));
   if (state & (GDK_WINDOW_STATE_WITHDRAWN | GDK_WINDOW_STATE_ICONIFIED))
     return FALSE;
 
@@ -253,6 +253,7 @@ ogmrip_progress_dialog_run (OGMRipProgressDialog *dialog, OGMJobSpawn *spawn, OG
 static void
 ogmrip_progress_dialog_progress (OGMRipProgressDialog *dialog, gdouble fraction)
 {
+  GtkWindow *parent;
   GTimeVal tv;
   gchar *str;
   gulong eta;
@@ -289,12 +290,13 @@ ogmrip_progress_dialog_progress (OGMRipProgressDialog *dialog, gdouble fraction)
   }
 #endif /* HAVE_LIBNOTIFY_SUPPORT */
 
-  if (GTK_WINDOW (dialog)->transient_parent)
+  parent = gtk_window_get_transient_for (GTK_WINDOW (dialog));
+  if (parent)
   {
     gchar *title;
 
     title = g_strdup_printf ("OGMRip: %s: %.0f%%", dialog->priv->label, CLAMP (fraction, 0.0, 1.0) * 100);
-    gtk_window_set_title (GTK_WINDOW (dialog)->transient_parent, title);
+    gtk_window_set_title (parent, title);
     g_free (title);
   }
 }
@@ -355,7 +357,7 @@ ogmrip_progress_dialog_class_init (OGMRipProgressDialogClass *klass)
 static void
 ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
 {
-  GtkWidget *root;
+  GtkWidget *area, *root, *image;
   GtkSizeGroup *group;
   GladeXML *xml;
 
@@ -377,17 +379,25 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
 
   group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_EDGE);
+  area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
 
-  dialog->priv->resume_button = gtk_button_new_with_image (_("Resume"), GTK_STOCK_MEDIA_PLAY);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (area), GTK_BUTTONBOX_EDGE);
+
+  dialog->priv->resume_button = gtk_button_new_with_mnemonic (_("Resume"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), dialog->priv->resume_button, OGMRIP_RESPONSE_RESUME);
   gtk_size_group_add_widget (group, dialog->priv->resume_button);
 
-  dialog->priv->suspend_button = gtk_button_new_with_image (_("Suspend"), GTK_STOCK_MEDIA_PAUSE);
+  image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PLAY, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->resume_button), image);
+
+  dialog->priv->suspend_button = gtk_button_new_with_mnemonic (_("Suspend"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), dialog->priv->suspend_button, OGMRIP_RESPONSE_SUSPEND);
   gtk_size_group_add_widget (group, dialog->priv->suspend_button);
   gtk_widget_show (dialog->priv->suspend_button);
 
+  image = gtk_image_new_from_stock (GTK_STOCK_MEDIA_PAUSE, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (dialog->priv->suspend_button), image);
+
   dialog->priv->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Progress"));
@@ -396,8 +406,10 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   root = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), root, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), root);
   gtk_widget_show (root);
 
 #ifdef HAVE_LIBNOTIFY_SUPPORT
@@ -434,8 +446,12 @@ ogmrip_progress_dialog_dispose (GObject *gobject)
   OGMRipProgressDialog *dialog = OGMRIP_PROGRESS_DIALOG (gobject);
 
   if (dialog->priv->encoding)
+  {
+    g_signal_handlers_disconnect_by_func (dialog->priv->encoding,
+        ogmrip_progress_dialog_task_event, dialog);
     g_object_unref (dialog->priv->encoding);
-  dialog->priv->encoding = NULL;
+    dialog->priv->encoding = NULL;
+  }
 
   if (dialog->priv->title)
     g_free (dialog->priv->title);
@@ -498,14 +514,15 @@ ogmrip_progress_dialog_set_encoding (OGMRipProgressDialog *dialog, OGMRipEncodin
 
     if (dialog->priv->encoding)
     {
-      g_signal_handlers_disconnect_by_func (dialog->priv->encoding, ogmrip_progress_dialog_task_event, dialog);
+      g_signal_handlers_disconnect_by_func (dialog->priv->encoding,
+          ogmrip_progress_dialog_task_event, dialog);
 
       g_object_unref (dialog->priv->encoding);
     }
 
     dialog->priv->encoding = encoding;
 
-    g_signal_connect_swapped_while_alive (encoding, "task",
+    g_signal_connect_swapped (encoding, "task",
         G_CALLBACK (ogmrip_progress_dialog_task_event), dialog);
 
     ogmrip_progress_dialog_set_title (dialog, ogmrip_encoding_get_label (encoding));
