@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 #include "ogmrip-queue-dialog.h"
 #include "ogmrip-options-dialog.h"
 #include "ogmrip-profiles-dialog.h"
+#include "ogmrip-profiles.h"
+#include "ogmrip-plugin.h"
 
 #include "ogmrip-helper.h"
 #include "ogmrip-gconf.h"
@@ -259,7 +261,39 @@ ogmrip_queue_dialog_list_row_activated (OGMRipQueueDialog *dialog, GtkTreePath *
     {
       if (!options_dialog)
       {
-        options_dialog = ogmrip_options_dialog_new_from_encoding (encoding);
+        GType container;
+        GSList *sections, *section;
+        gint n_audio, n_subp;
+        gchar *name;
+
+        options_dialog = ogmrip_options_dialog_new (OGMRIP_OPTIONS_DIALOG_EDIT);
+
+        n_audio = ogmrip_encoding_get_n_audio_streams (encoding);
+        n_subp = ogmrip_encoding_get_n_subp_streams (encoding);
+
+        sections = ogmrip_settings_get_subsections (settings, OGMRIP_GCONF_PROFILES);
+        for (section = sections; section; section = section->next)
+        {
+          if (ogmrip_settings_has_section (settings, section->data) &&
+              ogmrip_profiles_check_profile (section->data, NULL))
+          {
+            ogmrip_settings_get (settings, section->data, OGMRIP_GCONF_CONTAINER_FORMAT, &name, NULL);
+            container = ogmrip_gconf_get_container_type (section->data, name);
+            g_free (name);
+
+            if (ogmrip_plugin_get_container_max_audio (container) >= n_audio &&
+                ogmrip_plugin_get_container_max_subp (container) >= n_subp)
+            {
+              ogmrip_settings_get (settings, section->data, "name", &name, NULL);
+              ogmrip_options_dialog_add_profile (OGMRIP_OPTIONS_DIALOG (options_dialog), section->data, name);
+              g_free (name);
+            }
+          }
+          g_free (section->data);
+        }
+        g_slist_free (sections);
+
+        ogmrip_options_dialog_set_encoding (OGMRIP_OPTIONS_DIALOG (options_dialog), encoding);
         gtk_list_store_set (dialog->priv->store, &iter, COL_DIALOG, options_dialog, -1);
 
         g_object_set_data_full (G_OBJECT (options_dialog), "__row_reference__",
@@ -554,7 +588,7 @@ ogmrip_queue_dialog_init (OGMRipQueueDialog *dialog)
   "  </popup>"
   "</ui>";
 
-  GtkWidget *widget;
+  GtkWidget *area, *widget;
   GladeXML *xml;
 
   GtkActionGroup *action_group;
@@ -612,8 +646,10 @@ ogmrip_queue_dialog_init (OGMRipQueueDialog *dialog)
   g_signal_connect_swapped (dialog->priv->export_action, "activate",
       G_CALLBACK (ogmrip_queue_dialog_export_action_activated), dialog);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   widget = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (area), widget);
   gtk_widget_show (widget);
 
   dialog->priv->treeview = glade_xml_get_widget (xml, "treeview");
