@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ ogmrip_subp_options_dialog_class_init (OGMRipSubpOptionsDialogClass *klass)
 static void
 ogmrip_subp_options_dialog_init (OGMRipSubpOptionsDialog *dialog)
 {
-  GtkWidget *vbox1, *vbox2, *alignment, *table, *label;
+  GtkWidget *area, *vbox, *vbox1, *vbox2, *alignment, *table, *label;
   GladeXML *xml;
 
   dialog->priv = OGMRIP_SUBP_OPTIONS_DIALOG_GET_PRIVATE (dialog);
@@ -115,9 +115,15 @@ ogmrip_subp_options_dialog_init (OGMRipSubpOptionsDialog *dialog)
   gtk_window_set_title (GTK_WINDOW (dialog), _("Subtitles Options"));
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES);
 
+  area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+  vbox = gtk_vbox_new (FALSE, 12);
+  gtk_container_add (GTK_CONTAINER (area), vbox);
+  gtk_widget_show (vbox);
+
   vbox1 = gtk_vbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (vbox1), 6);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox1, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), vbox1, FALSE, FALSE, 0);
   gtk_widget_show (vbox1);
 
   vbox2 = gtk_vbox_new (FALSE, 6);
@@ -170,7 +176,7 @@ ogmrip_subp_options_dialog_init (OGMRipSubpOptionsDialog *dialog)
   gtk_widget_show (dialog->priv->default_button);
 
   dialog->priv->root = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), dialog->priv->root, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->root, TRUE, TRUE, 0);
   gtk_widget_show (dialog->priv->root);
 
   g_signal_connect_swapped (dialog->priv->default_button, "toggled",
