@@ -132,7 +132,7 @@ write_png (char *file_name, int x0, int y0, int w, int h, unsigned char *src, un
   fp = fopen (file_name, "wb");
   if (!fp)
   {
-    fprintf (stderr, "error, unable to open/create file: %s\n", file_name);
+    fprintf (stderr, "** ERROR: Unable to open/create file %s\n", file_name);
     return -1;
   }
 
@@ -148,7 +148,7 @@ write_png (char *file_name, int x0, int y0, int w, int h, unsigned char *src, un
     return -1;
   }
 
-  if (setjmp (png_ptr->jmpbuf))
+  if (setjmp (png_jmpbuf(png_ptr)))
   {
     png_destroy_write_struct (&png_ptr, &info_ptr);
     fclose (fp);
@@ -404,7 +404,7 @@ load_palette (char *palet_file, unsigned int *palette)
     {
       if (fscanf (file, "%d", &c) != 1)
       {
-        fprintf (stderr, "unable to get palette information from file '%s'\n", palet_file);
+        fprintf (stderr, "** ERROR: Unable to get palette information from file '%s'\n", palet_file);
         break;
       }
 
@@ -419,7 +419,7 @@ load_palette (char *palet_file, unsigned int *palette)
   else
   {
     palet_file[0] = 0;
-    fprintf (stderr, "unable to open %s, using defaults\n", palet_file);
+    fprintf (stderr, "** WARNING: Unable to open %s, using defaults\n", palet_file);
   }
 }
 
@@ -433,7 +433,7 @@ parse_expand (const char *optarg)
   if (optarg)
   {
     if (sscanf (optarg, "%ux%u", &w, &h) != 2)
-      fprintf (stderr, "unable to parse %s, using defaults\n", optarg);
+      fprintf (stderr, "** WARNING: Unable to parse %s, using defaults\n", optarg);
     else
     {
       width = w;
@@ -526,7 +526,7 @@ main (int argc, char **argv)
         return EXIT_SUCCESS;
         break;
       default:
-        fprintf (stderr, "Unknown option. Use -h to list all valid options.\n");
+        fprintf (stderr, "** ERROR: Unknown option. Use -h to list all valid options.\n");
         return EXIT_FAILURE;
         break;
     }
@@ -543,7 +543,7 @@ main (int argc, char **argv)
 
   if (strlen (output) > FILENAME_MAX)
   {
-    fprintf (stderr, "Error max length of base for filename creation is %d characters\n", FILENAME_MAX);
+    fprintf (stderr, "** ERROR: Error max length of base for filename creation is %d characters\n", FILENAME_MAX);
     return EXIT_FAILURE;
   }
 
@@ -551,7 +551,7 @@ main (int argc, char **argv)
   xml_file = fopen (filename, "w+");
   if (!xml_file)
   {
-    fprintf (stderr, "Error opening file %s\n", filename);
+    fprintf (stderr, "** ERROR: Cannot open file %s\n", filename);
     return EXIT_FAILURE;
   }
 
@@ -559,7 +559,7 @@ main (int argc, char **argv)
   if (!vobsub)
   {
     fclose (xml_file);
-    fprintf (stderr, "Error opening VobSub\n");
+    fprintf (stderr, "** ERROR: Cannot open VobSub\n");
     return EXIT_FAILURE;
   }
 
