@@ -1,6 +1,6 @@
 /* srttool-2 - Various manipulations of srtfiles
  * Copyright (C) 2002-2006 Arne Driescher <driescher@users.sf.net>
- * Copyright (C) 2006-2009 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2006-2010 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,12 +100,12 @@ parse_shift (const char *value)
 {
   if (sscanf (value, "%lf", &offset) != 1)
   {
-    fprintf (stderr, "Invalid parameter for option -d\n");
+    fprintf (stderr, "** ERROR: Invalid parameter for option -d\n");
     return -1;
   }
 
   if (verbose)
-    fprintf (stderr, "Using time offset of %lf\n", offset);
+    fprintf (stderr, "** ERROR: Using time offset of %lf\n", offset);
 
   return 0;
 }
@@ -115,7 +115,7 @@ parse_cut (const char *value)
 {
   if (sscanf (value, "%u,%u", &first_tag_number, &last_tag_number) == 0)
   {
-    fprintf (stderr, "Invalid parameter for option -c\n");
+    fprintf (stderr, "** ERROR: Invalid parameter for option -c\n");
     return -1;
   }
 
@@ -138,7 +138,7 @@ parse_adjust (const char *value)
   if (sscanf (value, "%u:%u:%u,%u", &adjustment.hour, 
         &adjustment.min, &adjustment.sec, &adjustment.msec) != 4)
   {
-    fprintf (stderr, "Invalid parameter for option -a\n");
+    fprintf (stderr, "** ERROR: Invalid parameter for option -a\n");
     return -1;
   }
 
@@ -158,7 +158,7 @@ parse_expand (const char *value)
 
   if (sscanf (value, "%lf", &expansion) != 1)
   {
-    fprintf (stderr, "Invalid parameter for option -e\n");
+    fprintf (stderr, "** ERROR: Invalid parameter for option -e\n");
     return -1;
   }
 
@@ -248,7 +248,7 @@ read_subp_header (xmlTextReader *reader)
 {
   if (xml_read (reader, "subtitles", XML_ELEMENT_NODE) < 0)
   {
-    fprintf (stderr, "Cannot find subtitles node\n");
+    fprintf (stderr, "** ERROR: Cannot find subtitles node\n");
     return -1;
   }
 
@@ -260,7 +260,7 @@ read_subp_footer (xmlTextReader *reader)
 {
   if (!xmlStrEqual (xmlTextReaderConstName (reader), (xmlChar *) "subtitles"))
   {
-    fprintf (stderr, "Cannot find subtitles ending node\n");
+    fprintf (stderr, "** ERROR: Cannot find subtitles ending node\n");
     return -1;
   }
 
@@ -278,21 +278,21 @@ read_subp_tag (xmlTextReader *reader, subp_tag_t *tag)
   if (xml_read (reader, "subtitle", XML_ELEMENT_NODE) < 0)
   {
     if (!xmlStrEqual (xmlTextReaderConstName (reader), (xmlChar *) "subtitles"))
-      fprintf (stderr, "Cannot find subtitle node\n");
+      fprintf (stderr, "** ERROR: Cannot find subtitle node\n");
     return -1;
   }
 
   value = (char *) xmlTextReaderGetAttribute (reader, (xmlChar *) "id");
   if (!value)
   {
-    fprintf (stderr, "Cannot get id property\n");
+    fprintf (stderr, "** ERROR: Cannot get id property\n");
     return -1;
   }
 
   /* read the current number */
   if (sscanf (value, "%u", &tag->number) != 1)
   {
-    fprintf (stderr, "Cannot parse id property (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot parse id property (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -325,20 +325,20 @@ read_subp_tag (xmlTextReader *reader, subp_tag_t *tag)
   {
     if (xml_read (reader, NULL, XML_TEXT_NODE) < 0)
     {
-      fprintf (stderr, "Cannot get text node for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get text node for subtitle %d\n", tag->number);
       return -1;
     }
 
     tag->text = (char *) xmlTextReaderValue (reader);
     if (!tag->text)
     {
-      fprintf (stderr, "Cannot get text content for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get text content for subtitle %d\n", tag->number);
       return -1;
     }
 
     if (xml_read (reader, "text", XML_ELEMENT_DECL) < 0)
     {
-      fprintf (stderr, "Cannot get text ending node for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get text ending node for subtitle %d\n", tag->number);
       return -1;
     }
   }
@@ -346,32 +346,32 @@ read_subp_tag (xmlTextReader *reader, subp_tag_t *tag)
   {
     if (xml_read (reader, NULL, XML_TEXT_NODE) < 0)
     {
-      fprintf (stderr, "Cannot get image node for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get image node for subtitle %d\n", tag->number);
       return -1;
     }
 
     tag->image = (char *) xmlTextReaderValue (reader);
     if (!tag->image)
     {
-      fprintf (stderr, "Cannot get image content for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get image content for subtitle %d\n", tag->number);
       return -1;
     }
 
     if (xml_read (reader, "image", XML_ELEMENT_DECL) < 0)
     {
-      fprintf (stderr, "Cannot get image ending node for subtitle %d\n", tag->number);
+      fprintf (stderr, "** ERROR: Cannot get image ending node for subtitle %d\n", tag->number);
       return -1;
     }
   }
   else
   {
-    fprintf (stderr, "Cannot find text or image node for subtitle %d\n", tag->number);
+    fprintf (stderr, "** ERROR: Cannot find text or image node for subtitle %d\n", tag->number);
     return -1;
   }
 
   if (xml_read (reader, "subtitle", XML_ELEMENT_DECL) < 0)
   {
-    fprintf (stderr, "Cannot find subtitle ending node\n");
+    fprintf (stderr, "** ERROR: Cannot find subtitle ending node\n");
     return -1;
   }
 
@@ -383,7 +383,7 @@ write_subp_header (FILE *file)
 {
   if (fprintf (file, "<subtitles>\n") < 0)
   {
-    fprintf (stderr, "Cannot write subtitles node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write subtitles node (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -395,7 +395,7 @@ write_subp_footer (FILE *file)
 {
   if (fprintf (file, "</subtitles>\n") < 0)
   {
-    fprintf (stderr, "Cannot write subtitles ending node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write subtitles ending node (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -410,7 +410,7 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
   /* write the tag number */
   if (fprintf (file, "id=\"%u\"", tag->number) < 0)
   {
-    fprintf (stderr, "Cannot write tag number (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write tag number (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -421,7 +421,7 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
       tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
       tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec) < 0)
   {
-    fprintf (stderr, "Cannot write time stamp (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write time stamp (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -443,7 +443,7 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
 
   if (fprintf (file, "  </subtitle>\n") < 0)
   {
-    fprintf (stderr, "Cannot write subtitle ending node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write subtitle ending node (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -453,30 +453,29 @@ write_subp_tag (FILE *file, subp_tag_t *tag)
 static int
 write_srt_tag (FILE *file, subp_tag_t *tag)
 {
-  if (fprintf (file, "%d%s", tag->number, newline) < 0)
-  {
-    fprintf (stderr, "Cannot write tag number (%s)\n", strerror (errno));
-    return -1;
-  }
-
-  if (fprintf (file, "%02u:%02u:%02u,%03u --> %02u:%02u:%02u,%03u%s",
-        tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
-        tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec, newline) < 0)
-  {
-    fprintf (stderr, "Cannot write time stamp (%s)\n", strerror (errno));
-    return -1;
-  }
-
   if (!tag->text)
+    fprintf (stderr, "** WARNING: Cannot write text (not defined)\n");
+  else
   {
-    fprintf (stderr, "Cannot write text (not defined)\n");
-    return -1;
-  }
+    if (fprintf (file, "%d%s", tag->number, newline) < 0)
+    {
+      fprintf (stderr, "** ERROR: Cannot write tag number (%s)\n", strerror (errno));
+      return -1;
+    }
 
-  if (fprintf (file, "%s%s%s", tag->text, newline, newline) < 0)
-  {
-    fprintf (stderr, "Cannot write text (%s)\n", strerror (errno));
-    return -1;
+    if (fprintf (file, "%02u:%02u:%02u,%03u --> %02u:%02u:%02u,%03u%s",
+          tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
+          tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec, newline) < 0)
+    {
+      fprintf (stderr, "** ERROR: Cannot write time stamp (%s)\n", strerror (errno));
+      return -1;
+    }
+
+    if (fprintf (file, "%s%s%s", tag->text, newline, newline) < 0)
+    {
+      fprintf (stderr, "** ERROR: Cannot write text (%s)\n", strerror (errno));
+      return -1;
+    }
   }
 
   return 0;
@@ -487,13 +486,13 @@ write_spumux_header (FILE *file)
 {
   if (fprintf (file, "<subpictures>\n") < 0)
   {
-    fprintf (stderr, "Cannot write subpictures node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write subpictures node (%s)\n", strerror (errno));
     return -1;
   }
 
   if (fprintf (file, "  <stream>\n") < 0)
   {
-    fprintf (stderr, "Cannot write stream node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write stream node (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -505,13 +504,13 @@ write_spumux_footer (FILE *file)
 {
   if (fprintf (file, "  </stream>\n") < 0)
   {
-    fprintf (stderr, "Cannot write stream ending node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write stream ending node (%s)\n", strerror (errno));
     return -1;
   }
 
   if (fprintf (file, "</subpictures>\n") < 0)
   {
-    fprintf (stderr, "Cannot write subpictures ending node (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot write subpictures ending node (%s)\n", strerror (errno));
     return -1;
   }
 
@@ -522,17 +521,16 @@ static int
 write_spumux_tag (FILE *file, subp_tag_t *tag)
 {
   if (!tag->image)
+    fprintf (stderr, "** WARNING: Cannot write spu node (no image)\n");
+  else
   {
-    fprintf (stderr, "Cannot write spu node (no image)\n");
-    return -1;
-  }
-
-  if (fprintf (file, "    <spu image=\"%s\" start=\"%02u:%02u:%02u.%03u\" end=\"%02u:%02u:%02u.%03u\" />\n",
-      tag->image, tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
-      tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec) < 0)
-  {
-    fprintf (stderr, "Cannot write spu node (%s)\n", strerror (errno));
-    return -1;
+    if (fprintf (file, "    <spu image=\"%s\" start=\"%02u:%02u:%02u.%03u\" end=\"%02u:%02u:%02u.%03u\" />\n",
+        tag->image, tag->start_time.hour, tag->start_time.min, tag->start_time.sec, tag->start_time.msec,
+        tag->stop_time.hour, tag->stop_time.min, tag->stop_time.sec, tag->stop_time.msec) < 0)
+    {
+      fprintf (stderr, "** ERROR: Cannot write spu node (%s)\n", strerror (errno));
+      return -1;
+    }
   }
 
   return 0;
@@ -642,18 +640,18 @@ substitute_txt (subp_tag_t *tag)
 
   if (sscanf (tag->image, "%[^\r\n]", filename) != 1)
   {
-    fprintf (stderr, "Cannot read substitution filename (%s)\n", strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot read substitution filename (%s)\n", strerror (errno));
     return -1;
   }
   strcat (filename, ".txt");
 
   if (verbose)
-    fprintf (stderr, "Reading substitution from file '%s'\n", filename);
+    fprintf (stderr, "** ERROR: Reading substitution from file '%s'\n", filename);
 
   fd = open (filename, O_RDONLY);
   if (fd < 0)
   {
-    fprintf (stderr, "Cannot open file '%s' for substitution (%s)\n", filename, strerror (errno));
+    fprintf (stderr, "** ERROR: Cannot open file '%s' for substitution (%s)\n", filename, strerror (errno));
     return -1;
   }
 
@@ -804,13 +802,13 @@ main (int argc, char *argv[])
     fd = open (input_file, O_RDONLY);
     if (fd < 0)
     {
-      fprintf (stderr, "Cannot open file %s for reading (%s)\n", input_file, strerror (errno));
+      fprintf (stderr, "** ERROR: Cannot open file %s for reading (%s)\n", input_file, strerror (errno));
       return EXIT_FAILURE;
     }
 
     if (dup2 (fd, STDIN_FILENO) < 0)
     {
-      fprintf (stderr, "Cannot ...\n");
+      fprintf (stderr, "** ERROR: Cannot ...\n");
       return EXIT_FAILURE;
     }
 
@@ -822,7 +820,7 @@ main (int argc, char *argv[])
   {
     if (!freopen (output_file, "w", stdout))
     {
-      fprintf (stderr, "Cannot open file %s for writing (%s)\n", input_file, strerror (errno));
+      fprintf (stderr, "** ERROR: Cannot open file %s for writing (%s)\n", input_file, strerror (errno));
       return EXIT_FAILURE;
     }
 
@@ -837,7 +835,7 @@ main (int argc, char *argv[])
   reader = xmlReaderForFd (STDIN_FILENO, NULL, NULL, 0);
   if (!reader)
   {
-    fprintf (stderr, "Cannot open XML reader\n");
+    fprintf (stderr, "** ERROR: Cannot open XML reader\n");
     return EXIT_FAILURE;
   }
 
